# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .agent_think_models_v1response import AgentThinkModelsV1ResponseParams
    from .agent_think_models_v1response_models_item import AgentThinkModelsV1ResponseModelsItemParams
    from .agent_think_models_v1response_models_item_id import AgentThinkModelsV1ResponseModelsItemIdParams
    from .agent_think_models_v1response_models_item_one import AgentThinkModelsV1ResponseModelsItemOneParams
    from .agent_think_models_v1response_models_item_three import AgentThinkModelsV1ResponseModelsItemThreeParams
    from .agent_think_models_v1response_models_item_two import AgentThinkModelsV1ResponseModelsItemTwoParams
    from .agent_think_models_v1response_models_item_zero import AgentThinkModelsV1ResponseModelsItemZeroParams
    from .anthropic import AnthropicParams
    from .aws_bedrock_think_provider import AwsBedrockThinkProviderParams
    from .aws_bedrock_think_provider_credentials import AwsBedrockThinkProviderCredentialsParams
    from .aws_polly_speak_provider import AwsPollySpeakProviderParams
    from .aws_polly_speak_provider_credentials import AwsPollySpeakProviderCredentialsParams
    from .billing_breakdown_v1response import BillingBreakdownV1ResponseParams
    from .billing_breakdown_v1response_resolution import BillingBreakdownV1ResponseResolutionParams
    from .billing_breakdown_v1response_results_item import BillingBreakdownV1ResponseResultsItemParams
    from .billing_breakdown_v1response_results_item_grouping import BillingBreakdownV1ResponseResultsItemGroupingParams
    from .cartesia import CartesiaParams
    from .cartesia_speak_provider_voice import CartesiaSpeakProviderVoiceParams
    from .create_key_v1response import CreateKeyV1ResponseParams
    from .create_project_distribution_credentials_v1response import CreateProjectDistributionCredentialsV1ResponseParams
    from .create_project_distribution_credentials_v1response_distribution_credentials import (
        CreateProjectDistributionCredentialsV1ResponseDistributionCredentialsParams,
    )
    from .create_project_distribution_credentials_v1response_member import (
        CreateProjectDistributionCredentialsV1ResponseMemberParams,
    )
    from .create_project_invite_v1response import CreateProjectInviteV1ResponseParams
    from .deepgram import DeepgramParams
    from .delete_project_invite_v1response import DeleteProjectInviteV1ResponseParams
    from .delete_project_key_v1response import DeleteProjectKeyV1ResponseParams
    from .delete_project_member_v1response import DeleteProjectMemberV1ResponseParams
    from .delete_project_v1response import DeleteProjectV1ResponseParams
    from .eleven_labs_speak_provider import ElevenLabsSpeakProviderParams
    from .error_response import ErrorResponseParams
    from .error_response_legacy_error import ErrorResponseLegacyErrorParams
    from .error_response_modern_error import ErrorResponseModernErrorParams
    from .get_model_v1response import GetModelV1ResponseParams
    from .get_model_v1response_batch import GetModelV1ResponseBatchParams
    from .get_model_v1response_metadata import GetModelV1ResponseMetadataParams
    from .get_model_v1response_metadata_metadata import GetModelV1ResponseMetadataMetadataParams
    from .get_project_balance_v1response import GetProjectBalanceV1ResponseParams
    from .get_project_distribution_credentials_v1response import GetProjectDistributionCredentialsV1ResponseParams
    from .get_project_distribution_credentials_v1response_distribution_credentials import (
        GetProjectDistributionCredentialsV1ResponseDistributionCredentialsParams,
    )
    from .get_project_distribution_credentials_v1response_member import (
        GetProjectDistributionCredentialsV1ResponseMemberParams,
    )
    from .get_project_key_v1response import GetProjectKeyV1ResponseParams
    from .get_project_key_v1response_item import GetProjectKeyV1ResponseItemParams
    from .get_project_key_v1response_item_member import GetProjectKeyV1ResponseItemMemberParams
    from .get_project_key_v1response_item_member_api_key import GetProjectKeyV1ResponseItemMemberApiKeyParams
    from .get_project_request_v1response import GetProjectRequestV1ResponseParams
    from .get_project_v1response import GetProjectV1ResponseParams
    from .google import GoogleParams
    from .grant_v1response import GrantV1ResponseParams
    from .groq import GroqParams
    from .leave_project_v1response import LeaveProjectV1ResponseParams
    from .list_billing_fields_v1response import ListBillingFieldsV1ResponseParams
    from .list_models_v1response import ListModelsV1ResponseParams
    from .list_models_v1response_stt_models import ListModelsV1ResponseSttModelsParams
    from .list_models_v1response_tts_models import ListModelsV1ResponseTtsModelsParams
    from .list_models_v1response_tts_models_metadata import ListModelsV1ResponseTtsModelsMetadataParams
    from .list_project_balances_v1response import ListProjectBalancesV1ResponseParams
    from .list_project_balances_v1response_balances_item import ListProjectBalancesV1ResponseBalancesItemParams
    from .list_project_distribution_credentials_v1response import ListProjectDistributionCredentialsV1ResponseParams
    from .list_project_distribution_credentials_v1response_distribution_credentials_item import (
        ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemParams,
    )
    from .list_project_distribution_credentials_v1response_distribution_credentials_item_distribution_credentials import (
        ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemDistributionCredentialsParams,
    )
    from .list_project_distribution_credentials_v1response_distribution_credentials_item_member import (
        ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemMemberParams,
    )
    from .list_project_invites_v1response import ListProjectInvitesV1ResponseParams
    from .list_project_invites_v1response_invites_item import ListProjectInvitesV1ResponseInvitesItemParams
    from .list_project_keys_v1response import ListProjectKeysV1ResponseParams
    from .list_project_keys_v1response_api_keys_item import ListProjectKeysV1ResponseApiKeysItemParams
    from .list_project_keys_v1response_api_keys_item_api_key import ListProjectKeysV1ResponseApiKeysItemApiKeyParams
    from .list_project_keys_v1response_api_keys_item_member import ListProjectKeysV1ResponseApiKeysItemMemberParams
    from .list_project_member_scopes_v1response import ListProjectMemberScopesV1ResponseParams
    from .list_project_members_v1response import ListProjectMembersV1ResponseParams
    from .list_project_members_v1response_members_item import ListProjectMembersV1ResponseMembersItemParams
    from .list_project_purchases_v1response import ListProjectPurchasesV1ResponseParams
    from .list_project_purchases_v1response_orders_item import ListProjectPurchasesV1ResponseOrdersItemParams
    from .list_project_requests_v1response import ListProjectRequestsV1ResponseParams
    from .list_projects_v1response import ListProjectsV1ResponseParams
    from .list_projects_v1response_projects_item import ListProjectsV1ResponseProjectsItemParams
    from .listen_v1accepted_response import ListenV1AcceptedResponseParams
    from .listen_v1response import ListenV1ResponseParams
    from .listen_v1response_metadata import ListenV1ResponseMetadataParams
    from .listen_v1response_metadata_intents_info import ListenV1ResponseMetadataIntentsInfoParams
    from .listen_v1response_metadata_sentiment_info import ListenV1ResponseMetadataSentimentInfoParams
    from .listen_v1response_metadata_summary_info import ListenV1ResponseMetadataSummaryInfoParams
    from .listen_v1response_metadata_topics_info import ListenV1ResponseMetadataTopicsInfoParams
    from .listen_v1response_results import ListenV1ResponseResultsParams
    from .listen_v1response_results_channels import ListenV1ResponseResultsChannelsParams
    from .listen_v1response_results_channels_item import ListenV1ResponseResultsChannelsItemParams
    from .listen_v1response_results_channels_item_alternatives_item import (
        ListenV1ResponseResultsChannelsItemAlternativesItemParams,
    )
    from .listen_v1response_results_channels_item_alternatives_item_entities_item import (
        ListenV1ResponseResultsChannelsItemAlternativesItemEntitiesItemParams,
    )
    from .listen_v1response_results_channels_item_alternatives_item_paragraphs import (
        ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParams,
    )
    from .listen_v1response_results_channels_item_alternatives_item_paragraphs_paragraphs_item import (
        ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemParams,
    )
    from .listen_v1response_results_channels_item_alternatives_item_paragraphs_paragraphs_item_sentences_item import (
        ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemSentencesItemParams,
    )
    from .listen_v1response_results_channels_item_alternatives_item_summaries_item import (
        ListenV1ResponseResultsChannelsItemAlternativesItemSummariesItemParams,
    )
    from .listen_v1response_results_channels_item_alternatives_item_topics_item import (
        ListenV1ResponseResultsChannelsItemAlternativesItemTopicsItemParams,
    )
    from .listen_v1response_results_channels_item_alternatives_item_words_item import (
        ListenV1ResponseResultsChannelsItemAlternativesItemWordsItemParams,
    )
    from .listen_v1response_results_channels_item_search_item import ListenV1ResponseResultsChannelsItemSearchItemParams
    from .listen_v1response_results_channels_item_search_item_hits_item import (
        ListenV1ResponseResultsChannelsItemSearchItemHitsItemParams,
    )
    from .listen_v1response_results_summary import ListenV1ResponseResultsSummaryParams
    from .listen_v1response_results_utterances import ListenV1ResponseResultsUtterancesParams
    from .listen_v1response_results_utterances_item import ListenV1ResponseResultsUtterancesItemParams
    from .listen_v1response_results_utterances_item_words_item import (
        ListenV1ResponseResultsUtterancesItemWordsItemParams,
    )
    from .listen_v2keyterm import ListenV2KeytermParams
    from .open_ai_speak_provider import OpenAiSpeakProviderParams
    from .open_ai_think_provider import OpenAiThinkProviderParams
    from .project_request_response import ProjectRequestResponseParams
    from .read_v1request import ReadV1RequestParams
    from .read_v1request_text import ReadV1RequestTextParams
    from .read_v1request_url import ReadV1RequestUrlParams
    from .read_v1response import ReadV1ResponseParams
    from .read_v1response_metadata import ReadV1ResponseMetadataParams
    from .read_v1response_metadata_metadata import ReadV1ResponseMetadataMetadataParams
    from .read_v1response_metadata_metadata_intents_info import ReadV1ResponseMetadataMetadataIntentsInfoParams
    from .read_v1response_metadata_metadata_sentiment_info import ReadV1ResponseMetadataMetadataSentimentInfoParams
    from .read_v1response_metadata_metadata_summary_info import ReadV1ResponseMetadataMetadataSummaryInfoParams
    from .read_v1response_metadata_metadata_topics_info import ReadV1ResponseMetadataMetadataTopicsInfoParams
    from .read_v1response_results import ReadV1ResponseResultsParams
    from .read_v1response_results_summary import ReadV1ResponseResultsSummaryParams
    from .read_v1response_results_summary_results import ReadV1ResponseResultsSummaryResultsParams
    from .read_v1response_results_summary_results_summary import ReadV1ResponseResultsSummaryResultsSummaryParams
    from .shared_intents import SharedIntentsParams
    from .shared_intents_results import SharedIntentsResultsParams
    from .shared_intents_results_intents import SharedIntentsResultsIntentsParams
    from .shared_intents_results_intents_segments_item import SharedIntentsResultsIntentsSegmentsItemParams
    from .shared_intents_results_intents_segments_item_intents_item import (
        SharedIntentsResultsIntentsSegmentsItemIntentsItemParams,
    )
    from .shared_sentiments import SharedSentimentsParams
    from .shared_sentiments_average import SharedSentimentsAverageParams
    from .shared_sentiments_segments_item import SharedSentimentsSegmentsItemParams
    from .shared_topics import SharedTopicsParams
    from .shared_topics_results import SharedTopicsResultsParams
    from .shared_topics_results_topics import SharedTopicsResultsTopicsParams
    from .shared_topics_results_topics_segments_item import SharedTopicsResultsTopicsSegmentsItemParams
    from .shared_topics_results_topics_segments_item_topics_item import (
        SharedTopicsResultsTopicsSegmentsItemTopicsItemParams,
    )
    from .speak_settings_v1 import SpeakSettingsV1Params
    from .speak_settings_v1endpoint import SpeakSettingsV1EndpointParams
    from .speak_settings_v1provider import (
        SpeakSettingsV1ProviderParams,
        SpeakSettingsV1Provider_AwsPollyParams,
        SpeakSettingsV1Provider_CartesiaParams,
        SpeakSettingsV1Provider_DeepgramParams,
        SpeakSettingsV1Provider_ElevenLabsParams,
        SpeakSettingsV1Provider_OpenAiParams,
    )
    from .think_settings_v1 import ThinkSettingsV1Params
    from .think_settings_v1context_length import ThinkSettingsV1ContextLengthParams
    from .think_settings_v1endpoint import ThinkSettingsV1EndpointParams
    from .think_settings_v1functions_item import ThinkSettingsV1FunctionsItemParams
    from .think_settings_v1functions_item_endpoint import ThinkSettingsV1FunctionsItemEndpointParams
    from .think_settings_v1provider import (
        ThinkSettingsV1ProviderParams,
        ThinkSettingsV1Provider_AnthropicParams,
        ThinkSettingsV1Provider_AwsBedrockParams,
        ThinkSettingsV1Provider_GoogleParams,
        ThinkSettingsV1Provider_GroqParams,
        ThinkSettingsV1Provider_OpenAiParams,
    )
    from .update_project_member_scopes_v1response import UpdateProjectMemberScopesV1ResponseParams
    from .update_project_v1response import UpdateProjectV1ResponseParams
    from .usage_breakdown_v1response import UsageBreakdownV1ResponseParams
    from .usage_breakdown_v1response_resolution import UsageBreakdownV1ResponseResolutionParams
    from .usage_breakdown_v1response_results_item import UsageBreakdownV1ResponseResultsItemParams
    from .usage_breakdown_v1response_results_item_grouping import UsageBreakdownV1ResponseResultsItemGroupingParams
    from .usage_fields_v1response import UsageFieldsV1ResponseParams
    from .usage_fields_v1response_models_item import UsageFieldsV1ResponseModelsItemParams
    from .usage_v1response import UsageV1ResponseParams
    from .usage_v1response_resolution import UsageV1ResponseResolutionParams
_dynamic_imports: typing.Dict[str, str] = {
    "AgentThinkModelsV1ResponseModelsItemIdParams": ".agent_think_models_v1response_models_item_id",
    "AgentThinkModelsV1ResponseModelsItemOneParams": ".agent_think_models_v1response_models_item_one",
    "AgentThinkModelsV1ResponseModelsItemParams": ".agent_think_models_v1response_models_item",
    "AgentThinkModelsV1ResponseModelsItemThreeParams": ".agent_think_models_v1response_models_item_three",
    "AgentThinkModelsV1ResponseModelsItemTwoParams": ".agent_think_models_v1response_models_item_two",
    "AgentThinkModelsV1ResponseModelsItemZeroParams": ".agent_think_models_v1response_models_item_zero",
    "AgentThinkModelsV1ResponseParams": ".agent_think_models_v1response",
    "AnthropicParams": ".anthropic",
    "AwsBedrockThinkProviderCredentialsParams": ".aws_bedrock_think_provider_credentials",
    "AwsBedrockThinkProviderParams": ".aws_bedrock_think_provider",
    "AwsPollySpeakProviderCredentialsParams": ".aws_polly_speak_provider_credentials",
    "AwsPollySpeakProviderParams": ".aws_polly_speak_provider",
    "BillingBreakdownV1ResponseParams": ".billing_breakdown_v1response",
    "BillingBreakdownV1ResponseResolutionParams": ".billing_breakdown_v1response_resolution",
    "BillingBreakdownV1ResponseResultsItemGroupingParams": ".billing_breakdown_v1response_results_item_grouping",
    "BillingBreakdownV1ResponseResultsItemParams": ".billing_breakdown_v1response_results_item",
    "CartesiaParams": ".cartesia",
    "CartesiaSpeakProviderVoiceParams": ".cartesia_speak_provider_voice",
    "CreateKeyV1ResponseParams": ".create_key_v1response",
    "CreateProjectDistributionCredentialsV1ResponseDistributionCredentialsParams": ".create_project_distribution_credentials_v1response_distribution_credentials",
    "CreateProjectDistributionCredentialsV1ResponseMemberParams": ".create_project_distribution_credentials_v1response_member",
    "CreateProjectDistributionCredentialsV1ResponseParams": ".create_project_distribution_credentials_v1response",
    "CreateProjectInviteV1ResponseParams": ".create_project_invite_v1response",
    "DeepgramParams": ".deepgram",
    "DeleteProjectInviteV1ResponseParams": ".delete_project_invite_v1response",
    "DeleteProjectKeyV1ResponseParams": ".delete_project_key_v1response",
    "DeleteProjectMemberV1ResponseParams": ".delete_project_member_v1response",
    "DeleteProjectV1ResponseParams": ".delete_project_v1response",
    "ElevenLabsSpeakProviderParams": ".eleven_labs_speak_provider",
    "ErrorResponseLegacyErrorParams": ".error_response_legacy_error",
    "ErrorResponseModernErrorParams": ".error_response_modern_error",
    "ErrorResponseParams": ".error_response",
    "GetModelV1ResponseBatchParams": ".get_model_v1response_batch",
    "GetModelV1ResponseMetadataMetadataParams": ".get_model_v1response_metadata_metadata",
    "GetModelV1ResponseMetadataParams": ".get_model_v1response_metadata",
    "GetModelV1ResponseParams": ".get_model_v1response",
    "GetProjectBalanceV1ResponseParams": ".get_project_balance_v1response",
    "GetProjectDistributionCredentialsV1ResponseDistributionCredentialsParams": ".get_project_distribution_credentials_v1response_distribution_credentials",
    "GetProjectDistributionCredentialsV1ResponseMemberParams": ".get_project_distribution_credentials_v1response_member",
    "GetProjectDistributionCredentialsV1ResponseParams": ".get_project_distribution_credentials_v1response",
    "GetProjectKeyV1ResponseItemMemberApiKeyParams": ".get_project_key_v1response_item_member_api_key",
    "GetProjectKeyV1ResponseItemMemberParams": ".get_project_key_v1response_item_member",
    "GetProjectKeyV1ResponseItemParams": ".get_project_key_v1response_item",
    "GetProjectKeyV1ResponseParams": ".get_project_key_v1response",
    "GetProjectRequestV1ResponseParams": ".get_project_request_v1response",
    "GetProjectV1ResponseParams": ".get_project_v1response",
    "GoogleParams": ".google",
    "GrantV1ResponseParams": ".grant_v1response",
    "GroqParams": ".groq",
    "LeaveProjectV1ResponseParams": ".leave_project_v1response",
    "ListBillingFieldsV1ResponseParams": ".list_billing_fields_v1response",
    "ListModelsV1ResponseParams": ".list_models_v1response",
    "ListModelsV1ResponseSttModelsParams": ".list_models_v1response_stt_models",
    "ListModelsV1ResponseTtsModelsMetadataParams": ".list_models_v1response_tts_models_metadata",
    "ListModelsV1ResponseTtsModelsParams": ".list_models_v1response_tts_models",
    "ListProjectBalancesV1ResponseBalancesItemParams": ".list_project_balances_v1response_balances_item",
    "ListProjectBalancesV1ResponseParams": ".list_project_balances_v1response",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemDistributionCredentialsParams": ".list_project_distribution_credentials_v1response_distribution_credentials_item_distribution_credentials",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemMemberParams": ".list_project_distribution_credentials_v1response_distribution_credentials_item_member",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemParams": ".list_project_distribution_credentials_v1response_distribution_credentials_item",
    "ListProjectDistributionCredentialsV1ResponseParams": ".list_project_distribution_credentials_v1response",
    "ListProjectInvitesV1ResponseInvitesItemParams": ".list_project_invites_v1response_invites_item",
    "ListProjectInvitesV1ResponseParams": ".list_project_invites_v1response",
    "ListProjectKeysV1ResponseApiKeysItemApiKeyParams": ".list_project_keys_v1response_api_keys_item_api_key",
    "ListProjectKeysV1ResponseApiKeysItemMemberParams": ".list_project_keys_v1response_api_keys_item_member",
    "ListProjectKeysV1ResponseApiKeysItemParams": ".list_project_keys_v1response_api_keys_item",
    "ListProjectKeysV1ResponseParams": ".list_project_keys_v1response",
    "ListProjectMemberScopesV1ResponseParams": ".list_project_member_scopes_v1response",
    "ListProjectMembersV1ResponseMembersItemParams": ".list_project_members_v1response_members_item",
    "ListProjectMembersV1ResponseParams": ".list_project_members_v1response",
    "ListProjectPurchasesV1ResponseOrdersItemParams": ".list_project_purchases_v1response_orders_item",
    "ListProjectPurchasesV1ResponseParams": ".list_project_purchases_v1response",
    "ListProjectRequestsV1ResponseParams": ".list_project_requests_v1response",
    "ListProjectsV1ResponseParams": ".list_projects_v1response",
    "ListProjectsV1ResponseProjectsItemParams": ".list_projects_v1response_projects_item",
    "ListenV1AcceptedResponseParams": ".listen_v1accepted_response",
    "ListenV1ResponseMetadataIntentsInfoParams": ".listen_v1response_metadata_intents_info",
    "ListenV1ResponseMetadataParams": ".listen_v1response_metadata",
    "ListenV1ResponseMetadataSentimentInfoParams": ".listen_v1response_metadata_sentiment_info",
    "ListenV1ResponseMetadataSummaryInfoParams": ".listen_v1response_metadata_summary_info",
    "ListenV1ResponseMetadataTopicsInfoParams": ".listen_v1response_metadata_topics_info",
    "ListenV1ResponseParams": ".listen_v1response",
    "ListenV1ResponseResultsChannelsItemAlternativesItemEntitiesItemParams": ".listen_v1response_results_channels_item_alternatives_item_entities_item",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemParams": ".listen_v1response_results_channels_item_alternatives_item_paragraphs_paragraphs_item",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemSentencesItemParams": ".listen_v1response_results_channels_item_alternatives_item_paragraphs_paragraphs_item_sentences_item",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParams": ".listen_v1response_results_channels_item_alternatives_item_paragraphs",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParams": ".listen_v1response_results_channels_item_alternatives_item",
    "ListenV1ResponseResultsChannelsItemAlternativesItemSummariesItemParams": ".listen_v1response_results_channels_item_alternatives_item_summaries_item",
    "ListenV1ResponseResultsChannelsItemAlternativesItemTopicsItemParams": ".listen_v1response_results_channels_item_alternatives_item_topics_item",
    "ListenV1ResponseResultsChannelsItemAlternativesItemWordsItemParams": ".listen_v1response_results_channels_item_alternatives_item_words_item",
    "ListenV1ResponseResultsChannelsItemParams": ".listen_v1response_results_channels_item",
    "ListenV1ResponseResultsChannelsItemSearchItemHitsItemParams": ".listen_v1response_results_channels_item_search_item_hits_item",
    "ListenV1ResponseResultsChannelsItemSearchItemParams": ".listen_v1response_results_channels_item_search_item",
    "ListenV1ResponseResultsChannelsParams": ".listen_v1response_results_channels",
    "ListenV1ResponseResultsParams": ".listen_v1response_results",
    "ListenV1ResponseResultsSummaryParams": ".listen_v1response_results_summary",
    "ListenV1ResponseResultsUtterancesItemParams": ".listen_v1response_results_utterances_item",
    "ListenV1ResponseResultsUtterancesItemWordsItemParams": ".listen_v1response_results_utterances_item_words_item",
    "ListenV1ResponseResultsUtterancesParams": ".listen_v1response_results_utterances",
    "ListenV2KeytermParams": ".listen_v2keyterm",
    "OpenAiSpeakProviderParams": ".open_ai_speak_provider",
    "OpenAiThinkProviderParams": ".open_ai_think_provider",
    "ProjectRequestResponseParams": ".project_request_response",
    "ReadV1RequestParams": ".read_v1request",
    "ReadV1RequestTextParams": ".read_v1request_text",
    "ReadV1RequestUrlParams": ".read_v1request_url",
    "ReadV1ResponseMetadataMetadataIntentsInfoParams": ".read_v1response_metadata_metadata_intents_info",
    "ReadV1ResponseMetadataMetadataParams": ".read_v1response_metadata_metadata",
    "ReadV1ResponseMetadataMetadataSentimentInfoParams": ".read_v1response_metadata_metadata_sentiment_info",
    "ReadV1ResponseMetadataMetadataSummaryInfoParams": ".read_v1response_metadata_metadata_summary_info",
    "ReadV1ResponseMetadataMetadataTopicsInfoParams": ".read_v1response_metadata_metadata_topics_info",
    "ReadV1ResponseMetadataParams": ".read_v1response_metadata",
    "ReadV1ResponseParams": ".read_v1response",
    "ReadV1ResponseResultsParams": ".read_v1response_results",
    "ReadV1ResponseResultsSummaryParams": ".read_v1response_results_summary",
    "ReadV1ResponseResultsSummaryResultsParams": ".read_v1response_results_summary_results",
    "ReadV1ResponseResultsSummaryResultsSummaryParams": ".read_v1response_results_summary_results_summary",
    "SharedIntentsParams": ".shared_intents",
    "SharedIntentsResultsIntentsParams": ".shared_intents_results_intents",
    "SharedIntentsResultsIntentsSegmentsItemIntentsItemParams": ".shared_intents_results_intents_segments_item_intents_item",
    "SharedIntentsResultsIntentsSegmentsItemParams": ".shared_intents_results_intents_segments_item",
    "SharedIntentsResultsParams": ".shared_intents_results",
    "SharedSentimentsAverageParams": ".shared_sentiments_average",
    "SharedSentimentsParams": ".shared_sentiments",
    "SharedSentimentsSegmentsItemParams": ".shared_sentiments_segments_item",
    "SharedTopicsParams": ".shared_topics",
    "SharedTopicsResultsParams": ".shared_topics_results",
    "SharedTopicsResultsTopicsParams": ".shared_topics_results_topics",
    "SharedTopicsResultsTopicsSegmentsItemParams": ".shared_topics_results_topics_segments_item",
    "SharedTopicsResultsTopicsSegmentsItemTopicsItemParams": ".shared_topics_results_topics_segments_item_topics_item",
    "SpeakSettingsV1EndpointParams": ".speak_settings_v1endpoint",
    "SpeakSettingsV1Params": ".speak_settings_v1",
    "SpeakSettingsV1ProviderParams": ".speak_settings_v1provider",
    "SpeakSettingsV1Provider_AwsPollyParams": ".speak_settings_v1provider",
    "SpeakSettingsV1Provider_CartesiaParams": ".speak_settings_v1provider",
    "SpeakSettingsV1Provider_DeepgramParams": ".speak_settings_v1provider",
    "SpeakSettingsV1Provider_ElevenLabsParams": ".speak_settings_v1provider",
    "SpeakSettingsV1Provider_OpenAiParams": ".speak_settings_v1provider",
    "ThinkSettingsV1ContextLengthParams": ".think_settings_v1context_length",
    "ThinkSettingsV1EndpointParams": ".think_settings_v1endpoint",
    "ThinkSettingsV1FunctionsItemEndpointParams": ".think_settings_v1functions_item_endpoint",
    "ThinkSettingsV1FunctionsItemParams": ".think_settings_v1functions_item",
    "ThinkSettingsV1Params": ".think_settings_v1",
    "ThinkSettingsV1ProviderParams": ".think_settings_v1provider",
    "ThinkSettingsV1Provider_AnthropicParams": ".think_settings_v1provider",
    "ThinkSettingsV1Provider_AwsBedrockParams": ".think_settings_v1provider",
    "ThinkSettingsV1Provider_GoogleParams": ".think_settings_v1provider",
    "ThinkSettingsV1Provider_GroqParams": ".think_settings_v1provider",
    "ThinkSettingsV1Provider_OpenAiParams": ".think_settings_v1provider",
    "UpdateProjectMemberScopesV1ResponseParams": ".update_project_member_scopes_v1response",
    "UpdateProjectV1ResponseParams": ".update_project_v1response",
    "UsageBreakdownV1ResponseParams": ".usage_breakdown_v1response",
    "UsageBreakdownV1ResponseResolutionParams": ".usage_breakdown_v1response_resolution",
    "UsageBreakdownV1ResponseResultsItemGroupingParams": ".usage_breakdown_v1response_results_item_grouping",
    "UsageBreakdownV1ResponseResultsItemParams": ".usage_breakdown_v1response_results_item",
    "UsageFieldsV1ResponseModelsItemParams": ".usage_fields_v1response_models_item",
    "UsageFieldsV1ResponseParams": ".usage_fields_v1response",
    "UsageV1ResponseParams": ".usage_v1response",
    "UsageV1ResponseResolutionParams": ".usage_v1response_resolution",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AgentThinkModelsV1ResponseModelsItemIdParams",
    "AgentThinkModelsV1ResponseModelsItemOneParams",
    "AgentThinkModelsV1ResponseModelsItemParams",
    "AgentThinkModelsV1ResponseModelsItemThreeParams",
    "AgentThinkModelsV1ResponseModelsItemTwoParams",
    "AgentThinkModelsV1ResponseModelsItemZeroParams",
    "AgentThinkModelsV1ResponseParams",
    "AnthropicParams",
    "AwsBedrockThinkProviderCredentialsParams",
    "AwsBedrockThinkProviderParams",
    "AwsPollySpeakProviderCredentialsParams",
    "AwsPollySpeakProviderParams",
    "BillingBreakdownV1ResponseParams",
    "BillingBreakdownV1ResponseResolutionParams",
    "BillingBreakdownV1ResponseResultsItemGroupingParams",
    "BillingBreakdownV1ResponseResultsItemParams",
    "CartesiaParams",
    "CartesiaSpeakProviderVoiceParams",
    "CreateKeyV1ResponseParams",
    "CreateProjectDistributionCredentialsV1ResponseDistributionCredentialsParams",
    "CreateProjectDistributionCredentialsV1ResponseMemberParams",
    "CreateProjectDistributionCredentialsV1ResponseParams",
    "CreateProjectInviteV1ResponseParams",
    "DeepgramParams",
    "DeleteProjectInviteV1ResponseParams",
    "DeleteProjectKeyV1ResponseParams",
    "DeleteProjectMemberV1ResponseParams",
    "DeleteProjectV1ResponseParams",
    "ElevenLabsSpeakProviderParams",
    "ErrorResponseLegacyErrorParams",
    "ErrorResponseModernErrorParams",
    "ErrorResponseParams",
    "GetModelV1ResponseBatchParams",
    "GetModelV1ResponseMetadataMetadataParams",
    "GetModelV1ResponseMetadataParams",
    "GetModelV1ResponseParams",
    "GetProjectBalanceV1ResponseParams",
    "GetProjectDistributionCredentialsV1ResponseDistributionCredentialsParams",
    "GetProjectDistributionCredentialsV1ResponseMemberParams",
    "GetProjectDistributionCredentialsV1ResponseParams",
    "GetProjectKeyV1ResponseItemMemberApiKeyParams",
    "GetProjectKeyV1ResponseItemMemberParams",
    "GetProjectKeyV1ResponseItemParams",
    "GetProjectKeyV1ResponseParams",
    "GetProjectRequestV1ResponseParams",
    "GetProjectV1ResponseParams",
    "GoogleParams",
    "GrantV1ResponseParams",
    "GroqParams",
    "LeaveProjectV1ResponseParams",
    "ListBillingFieldsV1ResponseParams",
    "ListModelsV1ResponseParams",
    "ListModelsV1ResponseSttModelsParams",
    "ListModelsV1ResponseTtsModelsMetadataParams",
    "ListModelsV1ResponseTtsModelsParams",
    "ListProjectBalancesV1ResponseBalancesItemParams",
    "ListProjectBalancesV1ResponseParams",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemDistributionCredentialsParams",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemMemberParams",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemParams",
    "ListProjectDistributionCredentialsV1ResponseParams",
    "ListProjectInvitesV1ResponseInvitesItemParams",
    "ListProjectInvitesV1ResponseParams",
    "ListProjectKeysV1ResponseApiKeysItemApiKeyParams",
    "ListProjectKeysV1ResponseApiKeysItemMemberParams",
    "ListProjectKeysV1ResponseApiKeysItemParams",
    "ListProjectKeysV1ResponseParams",
    "ListProjectMemberScopesV1ResponseParams",
    "ListProjectMembersV1ResponseMembersItemParams",
    "ListProjectMembersV1ResponseParams",
    "ListProjectPurchasesV1ResponseOrdersItemParams",
    "ListProjectPurchasesV1ResponseParams",
    "ListProjectRequestsV1ResponseParams",
    "ListProjectsV1ResponseParams",
    "ListProjectsV1ResponseProjectsItemParams",
    "ListenV1AcceptedResponseParams",
    "ListenV1ResponseMetadataIntentsInfoParams",
    "ListenV1ResponseMetadataParams",
    "ListenV1ResponseMetadataSentimentInfoParams",
    "ListenV1ResponseMetadataSummaryInfoParams",
    "ListenV1ResponseMetadataTopicsInfoParams",
    "ListenV1ResponseParams",
    "ListenV1ResponseResultsChannelsItemAlternativesItemEntitiesItemParams",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemParams",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemSentencesItemParams",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParams",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParams",
    "ListenV1ResponseResultsChannelsItemAlternativesItemSummariesItemParams",
    "ListenV1ResponseResultsChannelsItemAlternativesItemTopicsItemParams",
    "ListenV1ResponseResultsChannelsItemAlternativesItemWordsItemParams",
    "ListenV1ResponseResultsChannelsItemParams",
    "ListenV1ResponseResultsChannelsItemSearchItemHitsItemParams",
    "ListenV1ResponseResultsChannelsItemSearchItemParams",
    "ListenV1ResponseResultsChannelsParams",
    "ListenV1ResponseResultsParams",
    "ListenV1ResponseResultsSummaryParams",
    "ListenV1ResponseResultsUtterancesItemParams",
    "ListenV1ResponseResultsUtterancesItemWordsItemParams",
    "ListenV1ResponseResultsUtterancesParams",
    "ListenV2KeytermParams",
    "OpenAiSpeakProviderParams",
    "OpenAiThinkProviderParams",
    "ProjectRequestResponseParams",
    "ReadV1RequestParams",
    "ReadV1RequestTextParams",
    "ReadV1RequestUrlParams",
    "ReadV1ResponseMetadataMetadataIntentsInfoParams",
    "ReadV1ResponseMetadataMetadataParams",
    "ReadV1ResponseMetadataMetadataSentimentInfoParams",
    "ReadV1ResponseMetadataMetadataSummaryInfoParams",
    "ReadV1ResponseMetadataMetadataTopicsInfoParams",
    "ReadV1ResponseMetadataParams",
    "ReadV1ResponseParams",
    "ReadV1ResponseResultsParams",
    "ReadV1ResponseResultsSummaryParams",
    "ReadV1ResponseResultsSummaryResultsParams",
    "ReadV1ResponseResultsSummaryResultsSummaryParams",
    "SharedIntentsParams",
    "SharedIntentsResultsIntentsParams",
    "SharedIntentsResultsIntentsSegmentsItemIntentsItemParams",
    "SharedIntentsResultsIntentsSegmentsItemParams",
    "SharedIntentsResultsParams",
    "SharedSentimentsAverageParams",
    "SharedSentimentsParams",
    "SharedSentimentsSegmentsItemParams",
    "SharedTopicsParams",
    "SharedTopicsResultsParams",
    "SharedTopicsResultsTopicsParams",
    "SharedTopicsResultsTopicsSegmentsItemParams",
    "SharedTopicsResultsTopicsSegmentsItemTopicsItemParams",
    "SpeakSettingsV1EndpointParams",
    "SpeakSettingsV1Params",
    "SpeakSettingsV1ProviderParams",
    "SpeakSettingsV1Provider_AwsPollyParams",
    "SpeakSettingsV1Provider_CartesiaParams",
    "SpeakSettingsV1Provider_DeepgramParams",
    "SpeakSettingsV1Provider_ElevenLabsParams",
    "SpeakSettingsV1Provider_OpenAiParams",
    "ThinkSettingsV1ContextLengthParams",
    "ThinkSettingsV1EndpointParams",
    "ThinkSettingsV1FunctionsItemEndpointParams",
    "ThinkSettingsV1FunctionsItemParams",
    "ThinkSettingsV1Params",
    "ThinkSettingsV1ProviderParams",
    "ThinkSettingsV1Provider_AnthropicParams",
    "ThinkSettingsV1Provider_AwsBedrockParams",
    "ThinkSettingsV1Provider_GoogleParams",
    "ThinkSettingsV1Provider_GroqParams",
    "ThinkSettingsV1Provider_OpenAiParams",
    "UpdateProjectMemberScopesV1ResponseParams",
    "UpdateProjectV1ResponseParams",
    "UsageBreakdownV1ResponseParams",
    "UsageBreakdownV1ResponseResolutionParams",
    "UsageBreakdownV1ResponseResultsItemGroupingParams",
    "UsageBreakdownV1ResponseResultsItemParams",
    "UsageFieldsV1ResponseModelsItemParams",
    "UsageFieldsV1ResponseParams",
    "UsageV1ResponseParams",
    "UsageV1ResponseResolutionParams",
]



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..types.agent_v1settings_audio_output_encoding import AgentV1SettingsAudioOutputEncoding


class AgentV1SettingsAudioOutputParams(typing_extensions.TypedDict):
    """
    Audio output configuration settings
    """

    encoding: typing_extensions.NotRequired[AgentV1SettingsAudioOutputEncoding]
    """
    Audio encoding format for streaming TTS output
    """

    sample_rate: typing_extensions.NotRequired[float]
    """
    Sample rate in Hz
    """

    bitrate: typing_extensions.NotRequired[float]
    """
    Audio bitrate in bits per second
    """

    container: typing_extensions.NotRequired[str]
    """
    Audio container format. If omitted, defaults to 'none'
    """



# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ListenV1ResultsMetadataModelInfoParams(typing_extensions.TypedDict):
    name: str
    """
    The name of the model
    """

    version: str
    """
    The version of the model
    """

    arch: str
    """
    The arch of the model
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .agent_v1settings_agent import AgentV1SettingsAgentParams
from .agent_v1settings_audio import AgentV1SettingsAudioParams
from .agent_v1settings_flags import AgentV1SettingsFlagsParams


class AgentV1SettingsParams(typing_extensions.TypedDict):
    type: typing.Literal["Settings"]
    tags: typing_extensions.NotRequired[typing.Sequence[str]]
    """
    Tags to associate with the request
    """

    experimental: typing_extensions.NotRequired[bool]
    """
    To enable experimental features
    """

    flags: typing_extensions.NotRequired[AgentV1SettingsFlagsParams]
    mip_opt_out: typing_extensions.NotRequired[bool]
    """
    To opt out of Deepgram Model Improvement Program
    """

    audio: AgentV1SettingsAudioParams
    agent: AgentV1SettingsAgentParams



# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class GetProjectBalanceV1ResponseParams(typing_extensions.TypedDict):
    balance_id: typing_extensions.NotRequired[str]
    """
    The unique identifier of the balance
    """

    amount: typing_extensions.NotRequired[float]
    """
    The amount of the balance
    """

    units: typing_extensions.NotRequired[str]
    """
    The units of the balance, such as "USD"
    """

    purchase_order_id: typing_extensions.NotRequired[str]
    """
    Description or reference of the purchase
    """



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..types.listen_v1close_stream_type import ListenV1CloseStreamType


class ListenV1CloseStreamParams(typing_extensions.TypedDict):
    type: ListenV1CloseStreamType
    """
    Message type identifier
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .agent_think_models_v1response_models_item import AgentThinkModelsV1ResponseModelsItemParams


class AgentThinkModelsV1ResponseParams(typing_extensions.TypedDict):
    models: typing.Sequence[AgentThinkModelsV1ResponseModelsItemParams]



# This file was auto-generated by Fern from our API Definition.

import typing

BreakdownListRequestGroupingItem = typing.Union[
    typing.Literal["accessor", "deployment", "line_item", "tags"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

import typing

BreakdownGetRequestGrouping = typing.Union[
    typing.Literal["accessor", "endpoint", "feature_set", "models", "method", "tags", "deployment"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

import typing

MediaTranscribeRequestModel = typing.Union[
    typing.Literal[
        "nova-3",
        "nova-3-general",
        "nova-3-medical",
        "nova-2",
        "nova-2-general",
        "nova-2-meeting",
        "nova-2-finance",
        "nova-2-conversationalai",
        "nova-2-voicemail",
        "nova-2-video",
        "nova-2-medical",
        "nova-2-drivethru",
        "nova-2-automotive",
        "nova",
        "nova-general",
        "nova-phonecall",
        "nova-medical",
        "enhanced",
        "enhanced-general",
        "enhanced-meeting",
        "enhanced-phonecall",
        "enhanced-finance",
        "base",
        "meeting",
        "phonecall",
        "finance",
        "conversationalai",
        "voicemail",
        "video",
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .listen_v1results_metadata_model_info import ListenV1ResultsMetadataModelInfoParams


class ListenV1ResultsMetadataParams(typing_extensions.TypedDict):
    request_id: str
    """
    The request ID
    """

    model_info: ListenV1ResultsMetadataModelInfoParams
    model_uuid: str
    """
    The model UUID
    """



# This file was auto-generated by Fern from our API Definition.

import json
import typing

import websockets.sync.connection as websockets_sync_connection
from ...core.events import EventEmitterMixin, EventType
from ...core.pydantic_utilities import parse_obj_as
from .types.agent_v1agent_audio_done import AgentV1AgentAudioDone
from .types.agent_v1agent_started_speaking import AgentV1AgentStartedSpeaking
from .types.agent_v1agent_thinking import AgentV1AgentThinking
from .types.agent_v1conversation_text import AgentV1ConversationText
from .types.agent_v1error import AgentV1Error
from .types.agent_v1function_call_request import AgentV1FunctionCallRequest
from .types.agent_v1inject_agent_message import AgentV1InjectAgentMessage
from .types.agent_v1inject_user_message import AgentV1InjectUserMessage
from .types.agent_v1injection_refused import AgentV1InjectionRefused
from .types.agent_v1keep_alive import AgentV1KeepAlive
from .types.agent_v1prompt_updated import AgentV1PromptUpdated
from .types.agent_v1receive_function_call_response import AgentV1ReceiveFunctionCallResponse
from .types.agent_v1send_function_call_response import AgentV1SendFunctionCallResponse
from .types.agent_v1settings import AgentV1Settings
from .types.agent_v1settings_applied import AgentV1SettingsApplied
from .types.agent_v1speak_updated import AgentV1SpeakUpdated
from .types.agent_v1update_prompt import AgentV1UpdatePrompt
from .types.agent_v1update_speak import AgentV1UpdateSpeak
from .types.agent_v1user_started_speaking import AgentV1UserStartedSpeaking
from .types.agent_v1warning import AgentV1Warning
from .types.agent_v1welcome import AgentV1Welcome

try:
    from websockets.legacy.client import WebSocketClientProtocol  # type: ignore
except ImportError:
    from websockets import WebSocketClientProtocol  # type: ignore

def _sanitize_numeric_types(obj: typing.Any) -> typing.Any:
    """
    Recursively convert float values that are whole numbers to int.

    Workaround for Fern-generated models that type integer API fields
    (like sample_rate) as float, causing JSON serialization to produce
    values like 44100.0 instead of 44100. The Deepgram API rejects
    float representations of integer fields.

    See: https://github.com/deepgram/internal-api-specs/issues/205
    """
    if isinstance(obj, dict):
        return {k: _sanitize_numeric_types(v) for k, v in obj.items()}
    elif isinstance(obj, list):
        return [_sanitize_numeric_types(item) for item in obj]
    elif isinstance(obj, float) and obj.is_integer():
        return int(obj)
    return obj


V1SocketClientResponse = typing.Union[
    AgentV1ReceiveFunctionCallResponse,
    AgentV1PromptUpdated,
    AgentV1SpeakUpdated,
    AgentV1InjectionRefused,
    AgentV1Welcome,
    AgentV1SettingsApplied,
    AgentV1ConversationText,
    AgentV1UserStartedSpeaking,
    AgentV1AgentThinking,
    AgentV1FunctionCallRequest,
    AgentV1AgentStartedSpeaking,
    AgentV1AgentAudioDone,
    AgentV1Error,
    AgentV1Warning,
    bytes,
]


class AsyncV1SocketClient(EventEmitterMixin):
    def __init__(self, *, websocket: WebSocketClientProtocol):
        super().__init__()
        self._websocket = websocket

    async def __aiter__(self):
        async for message in self._websocket:
            if isinstance(message, bytes):
                yield message
            else:
                yield parse_obj_as(V1SocketClientResponse, json.loads(message))  # type: ignore

    async def start_listening(self):
        """
        Start listening for messages on the websocket connection.

        Emits events in the following order:
        - EventType.OPEN when connection is established
        - EventType.MESSAGE for each message received
        - EventType.ERROR if an error occurs
        - EventType.CLOSE when connection is closed
        """
        await self._emit_async(EventType.OPEN, None)
        try:
            async for raw_message in self._websocket:
                if isinstance(raw_message, bytes):
                    parsed = raw_message
                else:
                    json_data = json.loads(raw_message)
                    parsed = parse_obj_as(V1SocketClientResponse, json_data)  # type: ignore
                await self._emit_async(EventType.MESSAGE, parsed)
        except Exception as exc:
            await self._emit_async(EventType.ERROR, exc)
        finally:
            await self._emit_async(EventType.CLOSE, None)

    async def send_settings(self, message: AgentV1Settings) -> None:
        """
        Send a message to the websocket connection.
        The message will be sent as a AgentV1Settings.
        """
        await self._send_model(message)

    async def send_update_speak(self, message: AgentV1UpdateSpeak) -> None:
        """
        Send a message to the websocket connection.
        The message will be sent as a AgentV1UpdateSpeak.
        """
        await self._send_model(message)

    async def send_inject_user_message(self, message: AgentV1InjectUserMessage) -> None:
        """
        Send a message to the websocket connection.
        The message will be sent as a AgentV1InjectUserMessage.
        """
        await self._send_model(message)

    async def send_inject_agent_message(self, message: AgentV1InjectAgentMessage) -> None:
        """
        Send a message to the websocket connection.
        The message will be sent as a AgentV1InjectAgentMessage.
        """
        await self._send_model(message)

    async def send_function_call_response(self, message: AgentV1SendFunctionCallResponse) -> None:
        """
        Send a message to the websocket connection.
        The message will be sent as a AgentV1SendFunctionCallResponse.
        """
        await self._send_model(message)

    async def send_keep_alive(self, message: typing.Optional[AgentV1KeepAlive] = None) -> None:
        """
        Send a message to the websocket connection.
        The message will be sent as a AgentV1KeepAlive.
        """
        await self._send_model(message or AgentV1KeepAlive())

    async def send_update_prompt(self, message: AgentV1UpdatePrompt) -> None:
        """
        Send a message to the websocket connection.
        The message will be sent as a AgentV1UpdatePrompt.
        """
        await self._send_model(message)

    async def send_media(self, message: bytes) -> None:
        """
        Send a message to the websocket connection.
        The message will be sent as a bytes.
        """
        await self._send(message)

    async def recv(self) -> V1SocketClientResponse:
        """
        Receive a message from the websocket connection.
        """
        data = await self._websocket.recv()
        if isinstance(data, bytes):
            return data  # type: ignore
        json_data = json.loads(data)
        return parse_obj_as(V1SocketClientResponse, json_data)  # type: ignore

    async def _send(self, data: typing.Any) -> None:
        """
        Send a message to the websocket connection.
        """
        if isinstance(data, dict):
            data = json.dumps(data)
        await self._websocket.send(data)

    async def _send_model(self, data: typing.Any) -> None:
        """
        Send a Pydantic model to the websocket connection.
        """
        await self._send(_sanitize_numeric_types(data.dict()))


class V1SocketClient(EventEmitterMixin):
    def __init__(self, *, websocket: websockets_sync_connection.Connection):
        super().__init__()
        self._websocket = websocket

    def __iter__(self):
        for message in self._websocket:
            if isinstance(message, bytes):
                yield message
            else:
                yield parse_obj_as(V1SocketClientResponse, json.loads(message))  # type: ignore

    def start_listening(self):
        """
        Start listening for messages on the websocket connection.

        Emits events in the following order:
        - EventType.OPEN when connection is established
        - EventType.MESSAGE for each message received
        - EventType.ERROR if an error occurs
        - EventType.CLOSE when connection is closed
        """
        self._emit(EventType.OPEN, None)
        try:
            for raw_message in self._websocket:
                if isinstance(raw_message, bytes):
                    parsed = raw_message
                else:
                    json_data = json.loads(raw_message)
                    parsed = parse_obj_as(V1SocketClientResponse, json_data)  # type: ignore
                self._emit(EventType.MESSAGE, parsed)
        except Exception as exc:
            self._emit(EventType.ERROR, exc)
        finally:
            self._emit(EventType.CLOSE, None)

    def send_settings(self, message: AgentV1Settings) -> None:
        """
        Send a message to the websocket connection.
        The message will be sent as a AgentV1Settings.
        """
        self._send_model(message)

    def send_update_speak(self, message: AgentV1UpdateSpeak) -> None:
        """
        Send a message to the websocket connection.
        The message will be sent as a AgentV1UpdateSpeak.
        """
        self._send_model(message)

    def send_inject_user_message(self, message: AgentV1InjectUserMessage) -> None:
        """
        Send a message to the websocket connection.
        The message will be sent as a AgentV1InjectUserMessage.
        """
        self._send_model(message)

    def send_inject_agent_message(self, message: AgentV1InjectAgentMessage) -> None:
        """
        Send a message to the websocket connection.
        The message will be sent as a AgentV1InjectAgentMessage.
        """
        self._send_model(message)

    def send_function_call_response(self, message: AgentV1SendFunctionCallResponse) -> None:
        """
        Send a message to the websocket connection.
        The message will be sent as a AgentV1SendFunctionCallResponse.
        """
        self._send_model(message)

    def send_keep_alive(self, message: typing.Optional[AgentV1KeepAlive] = None) -> None:
        """
        Send a message to the websocket connection.
        The message will be sent as a AgentV1KeepAlive.
        """
        self._send_model(message or AgentV1KeepAlive())

    def send_update_prompt(self, message: AgentV1UpdatePrompt) -> None:
        """
        Send a message to the websocket connection.
        The message will be sent as a AgentV1UpdatePrompt.
        """
        self._send_model(message)

    def send_media(self, message: bytes) -> None:
        """
        Send a message to the websocket connection.
        The message will be sent as a bytes.
        """
        self._send(message)

    def recv(self) -> V1SocketClientResponse:
        """
        Receive a message from the websocket connection.
        """
        data = self._websocket.recv()
        if isinstance(data, bytes):
            return data  # type: ignore
        json_data = json.loads(data)
        return parse_obj_as(V1SocketClientResponse, json_data)  # type: ignore

    def _send(self, data: typing.Any) -> None:
        """
        Send a message to the websocket connection.
        """
        if isinstance(data, dict):
            data = json.dumps(data)
        self._websocket.send(data)

    def _send_model(self, data: typing.Any) -> None:
        """
        Send a Pydantic model to the websocket connection.
        """
        self._send(_sanitize_numeric_types(data.dict()))



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .listen_v1response_results_channels_item_search_item_hits_item import (
    ListenV1ResponseResultsChannelsItemSearchItemHitsItemParams,
)


class ListenV1ResponseResultsChannelsItemSearchItemParams(typing_extensions.TypedDict):
    query: typing_extensions.NotRequired[str]
    hits: typing_extensions.NotRequired[typing.Sequence[ListenV1ResponseResultsChannelsItemSearchItemHitsItemParams]]



# This file was auto-generated by Fern from our API Definition.

import typing

from .agent_think_models_v1response_models_item_id import AgentThinkModelsV1ResponseModelsItemIdParams
from .agent_think_models_v1response_models_item_one import AgentThinkModelsV1ResponseModelsItemOneParams
from .agent_think_models_v1response_models_item_three import AgentThinkModelsV1ResponseModelsItemThreeParams
from .agent_think_models_v1response_models_item_two import AgentThinkModelsV1ResponseModelsItemTwoParams
from .agent_think_models_v1response_models_item_zero import AgentThinkModelsV1ResponseModelsItemZeroParams

AgentThinkModelsV1ResponseModelsItemParams = typing.Union[
    AgentThinkModelsV1ResponseModelsItemZeroParams,
    AgentThinkModelsV1ResponseModelsItemOneParams,
    AgentThinkModelsV1ResponseModelsItemTwoParams,
    AgentThinkModelsV1ResponseModelsItemThreeParams,
    AgentThinkModelsV1ResponseModelsItemIdParams,
]



# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ListProjectKeysV1ResponseApiKeysItemMemberParams(typing_extensions.TypedDict):
    member_id: typing_extensions.NotRequired[str]
    email: typing_extensions.NotRequired[str]



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..types.aws_bedrock_think_provider_model import AwsBedrockThinkProviderModel
from .aws_bedrock_think_provider_credentials import AwsBedrockThinkProviderCredentialsParams


class AwsBedrockThinkProviderParams(typing_extensions.TypedDict):
    type: typing.Literal["aws_bedrock"]
    model: AwsBedrockThinkProviderModel
    """
    AWS Bedrock model to use
    """

    temperature: typing_extensions.NotRequired[float]
    """
    AWS Bedrock temperature (0-2)
    """

    credentials: typing_extensions.NotRequired[AwsBedrockThinkProviderCredentialsParams]
    """
    AWS credentials type (STS short-lived or IAM long-lived)
    """



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .read_v1response_results_summary_results import ReadV1ResponseResultsSummaryResultsParams


class ReadV1ResponseResultsSummaryParams(typing_extensions.TypedDict):
    """
    Output whenever `summary=true` is used
    """

    results: typing_extensions.NotRequired[ReadV1ResponseResultsSummaryResultsParams]



# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class SharedSentimentsAverageParams(typing_extensions.TypedDict):
    sentiment: typing_extensions.NotRequired[str]
    sentiment_score: typing_extensions.NotRequired[float]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .think_settings_v1functions_item_endpoint import ThinkSettingsV1FunctionsItemEndpoint


class ThinkSettingsV1FunctionsItem(UniversalBaseModel):
    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Function name
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Function description
    """

    parameters: typing.Optional[typing.Dict[str, typing.Any]] = pydantic.Field(default=None)
    """
    Function parameters
    """

    endpoint: typing.Optional[ThinkSettingsV1FunctionsItemEndpoint] = pydantic.Field(default=None)
    """
    The Function endpoint to call. if not passed, function is called client-side
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class AgentV1AgentStartedSpeakingParams(typing_extensions.TypedDict):
    type: typing.Literal["AgentStartedSpeaking"]
    """
    Message type identifier for agent started speaking
    """

    total_latency: float
    """
    Seconds from receiving the user's utterance to producing the agent's reply
    """

    tts_latency: float
    """
    The portion of total latency attributable to text-to-speech
    """

    ttt_latency: float
    """
    The portion of total latency attributable to text-to-text (usually an LLM)
    """



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from .....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .....core.request_options import RequestOptions
from .....types.get_project_request_v1response import GetProjectRequestV1Response
from .....types.list_project_requests_v1response import ListProjectRequestsV1Response
from .raw_client import AsyncRawRequestsClient, RawRequestsClient
from .types.requests_list_request_deployment import RequestsListRequestDeployment
from .types.requests_list_request_endpoint import RequestsListRequestEndpoint
from .types.requests_list_request_method import RequestsListRequestMethod
from .types.requests_list_request_status import RequestsListRequestStatus


class RequestsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawRequestsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawRequestsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawRequestsClient
        """
        return self._raw_client

    def list(
        self,
        project_id: str,
        *,
        start: typing.Optional[dt.datetime] = None,
        end: typing.Optional[dt.datetime] = None,
        limit: typing.Optional[float] = None,
        page: typing.Optional[float] = None,
        accessor: typing.Optional[str] = None,
        request_id: typing.Optional[str] = None,
        deployment: typing.Optional[RequestsListRequestDeployment] = None,
        endpoint: typing.Optional[RequestsListRequestEndpoint] = None,
        method: typing.Optional[RequestsListRequestMethod] = None,
        status: typing.Optional[RequestsListRequestStatus] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ListProjectRequestsV1Response:
        """
        Generates a list of requests for a specific project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        start : typing.Optional[dt.datetime]
            Start date of the requested date range. Formats accepted are YYYY-MM-DD, YYYY-MM-DDTHH:MM:SS, or YYYY-MM-DDTHH:MM:SS+HH:MM

        end : typing.Optional[dt.datetime]
            End date of the requested date range. Formats accepted are YYYY-MM-DD, YYYY-MM-DDTHH:MM:SS, or YYYY-MM-DDTHH:MM:SS+HH:MM

        limit : typing.Optional[float]
            Number of results to return per page. Default 10. Range [1,1000]

        page : typing.Optional[float]
            Navigate and return the results to retrieve specific portions of information of the response

        accessor : typing.Optional[str]
            Filter for requests where a specific accessor was used

        request_id : typing.Optional[str]
            Filter for a specific request id

        deployment : typing.Optional[RequestsListRequestDeployment]
            Filter for requests where a specific deployment was used

        endpoint : typing.Optional[RequestsListRequestEndpoint]
            Filter for requests where a specific endpoint was used

        method : typing.Optional[RequestsListRequestMethod]
            Filter for requests where a specific method was used

        status : typing.Optional[RequestsListRequestStatus]
            Filter for requests that succeeded (status code < 300) or failed (status code >=400)

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ListProjectRequestsV1Response
            A list of requests for a specific project

        Examples
        --------
        import datetime

        from deepgram import DeepgramClient

        client = DeepgramClient(
            api_key="YOUR_API_KEY",
        )
        client.manage.v1.projects.requests.list(
            project_id="123456-7890-1234-5678-901234",
            start=datetime.datetime.fromisoformat(
                "2024-01-15 09:30:00+00:00",
            ),
            end=datetime.datetime.fromisoformat(
                "2024-01-15 09:30:00+00:00",
            ),
            limit=1.1,
            page=1.1,
            accessor="12345678-1234-1234-1234-123456789012",
            request_id="12345678-1234-1234-1234-123456789012",
            deployment="hosted",
            endpoint="listen",
            method="sync",
            status="succeeded",
        )
        """
        _response = self._raw_client.list(
            project_id,
            start=start,
            end=end,
            limit=limit,
            page=page,
            accessor=accessor,
            request_id=request_id,
            deployment=deployment,
            endpoint=endpoint,
            method=method,
            status=status,
            request_options=request_options,
        )
        return _response.data

    def get(
        self, project_id: str, request_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetProjectRequestV1Response:
        """
        Retrieves a specific request for a specific project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        request_id : str
            The unique identifier of the request

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetProjectRequestV1Response
            A specific request for a specific project

        Examples
        --------
        from deepgram import DeepgramClient

        client = DeepgramClient(
            api_key="YOUR_API_KEY",
        )
        client.manage.v1.projects.requests.get(
            project_id="123456-7890-1234-5678-901234",
            request_id="123456-7890-1234-5678-901234",
        )
        """
        _response = self._raw_client.get(project_id, request_id, request_options=request_options)
        return _response.data


class AsyncRequestsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawRequestsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawRequestsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawRequestsClient
        """
        return self._raw_client

    async def list(
        self,
        project_id: str,
        *,
        start: typing.Optional[dt.datetime] = None,
        end: typing.Optional[dt.datetime] = None,
        limit: typing.Optional[float] = None,
        page: typing.Optional[float] = None,
        accessor: typing.Optional[str] = None,
        request_id: typing.Optional[str] = None,
        deployment: typing.Optional[RequestsListRequestDeployment] = None,
        endpoint: typing.Optional[RequestsListRequestEndpoint] = None,
        method: typing.Optional[RequestsListRequestMethod] = None,
        status: typing.Optional[RequestsListRequestStatus] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ListProjectRequestsV1Response:
        """
        Generates a list of requests for a specific project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        start : typing.Optional[dt.datetime]
            Start date of the requested date range. Formats accepted are YYYY-MM-DD, YYYY-MM-DDTHH:MM:SS, or YYYY-MM-DDTHH:MM:SS+HH:MM

        end : typing.Optional[dt.datetime]
            End date of the requested date range. Formats accepted are YYYY-MM-DD, YYYY-MM-DDTHH:MM:SS, or YYYY-MM-DDTHH:MM:SS+HH:MM

        limit : typing.Optional[float]
            Number of results to return per page. Default 10. Range [1,1000]

        page : typing.Optional[float]
            Navigate and return the results to retrieve specific portions of information of the response

        accessor : typing.Optional[str]
            Filter for requests where a specific accessor was used

        request_id : typing.Optional[str]
            Filter for a specific request id

        deployment : typing.Optional[RequestsListRequestDeployment]
            Filter for requests where a specific deployment was used

        endpoint : typing.Optional[RequestsListRequestEndpoint]
            Filter for requests where a specific endpoint was used

        method : typing.Optional[RequestsListRequestMethod]
            Filter for requests where a specific method was used

        status : typing.Optional[RequestsListRequestStatus]
            Filter for requests that succeeded (status code < 300) or failed (status code >=400)

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ListProjectRequestsV1Response
            A list of requests for a specific project

        Examples
        --------
        import asyncio
        import datetime

        from deepgram import AsyncDeepgramClient

        client = AsyncDeepgramClient(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.manage.v1.projects.requests.list(
                project_id="123456-7890-1234-5678-901234",
                start=datetime.datetime.fromisoformat(
                    "2024-01-15 09:30:00+00:00",
                ),
                end=datetime.datetime.fromisoformat(
                    "2024-01-15 09:30:00+00:00",
                ),
                limit=1.1,
                page=1.1,
                accessor="12345678-1234-1234-1234-123456789012",
                request_id="12345678-1234-1234-1234-123456789012",
                deployment="hosted",
                endpoint="listen",
                method="sync",
                status="succeeded",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list(
            project_id,
            start=start,
            end=end,
            limit=limit,
            page=page,
            accessor=accessor,
            request_id=request_id,
            deployment=deployment,
            endpoint=endpoint,
            method=method,
            status=status,
            request_options=request_options,
        )
        return _response.data

    async def get(
        self, project_id: str, request_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetProjectRequestV1Response:
        """
        Retrieves a specific request for a specific project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        request_id : str
            The unique identifier of the request

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetProjectRequestV1Response
            A specific request for a specific project

        Examples
        --------
        import asyncio

        from deepgram import AsyncDeepgramClient

        client = AsyncDeepgramClient(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.manage.v1.projects.requests.get(
                project_id="123456-7890-1234-5678-901234",
                request_id="123456-7890-1234-5678-901234",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get(project_id, request_id, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .aws_polly_speak_provider_credentials_type import AwsPollySpeakProviderCredentialsType


class AwsPollySpeakProviderCredentials(UniversalBaseModel):
    type: AwsPollySpeakProviderCredentialsType
    region: str
    access_key_id: str
    secret_access_key: str
    session_token: typing.Optional[str] = pydantic.Field(default=None)
    """
    Required for STS only
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .get_project_key_v1response_item_member import GetProjectKeyV1ResponseItemMemberParams


class GetProjectKeyV1ResponseItemParams(typing_extensions.TypedDict):
    member: typing_extensions.NotRequired[GetProjectKeyV1ResponseItemMemberParams]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .agent_think_models_v1response import AgentThinkModelsV1Response
    from .agent_think_models_v1response_models_item import AgentThinkModelsV1ResponseModelsItem
    from .agent_think_models_v1response_models_item_id import AgentThinkModelsV1ResponseModelsItemId
    from .agent_think_models_v1response_models_item_one import AgentThinkModelsV1ResponseModelsItemOne
    from .agent_think_models_v1response_models_item_one_id import AgentThinkModelsV1ResponseModelsItemOneId
    from .agent_think_models_v1response_models_item_three import AgentThinkModelsV1ResponseModelsItemThree
    from .agent_think_models_v1response_models_item_two import AgentThinkModelsV1ResponseModelsItemTwo
    from .agent_think_models_v1response_models_item_two_id import AgentThinkModelsV1ResponseModelsItemTwoId
    from .agent_think_models_v1response_models_item_zero import AgentThinkModelsV1ResponseModelsItemZero
    from .agent_think_models_v1response_models_item_zero_id import AgentThinkModelsV1ResponseModelsItemZeroId
    from .anthropic import Anthropic
    from .anthropic_think_provider_model import AnthropicThinkProviderModel
    from .aws_bedrock_think_provider import AwsBedrockThinkProvider
    from .aws_bedrock_think_provider_credentials import AwsBedrockThinkProviderCredentials
    from .aws_bedrock_think_provider_credentials_type import AwsBedrockThinkProviderCredentialsType
    from .aws_bedrock_think_provider_model import AwsBedrockThinkProviderModel
    from .aws_polly_speak_provider import AwsPollySpeakProvider
    from .aws_polly_speak_provider_credentials import AwsPollySpeakProviderCredentials
    from .aws_polly_speak_provider_credentials_type import AwsPollySpeakProviderCredentialsType
    from .aws_polly_speak_provider_engine import AwsPollySpeakProviderEngine
    from .aws_polly_speak_provider_voice import AwsPollySpeakProviderVoice
    from .billing_breakdown_v1response import BillingBreakdownV1Response
    from .billing_breakdown_v1response_resolution import BillingBreakdownV1ResponseResolution
    from .billing_breakdown_v1response_results_item import BillingBreakdownV1ResponseResultsItem
    from .billing_breakdown_v1response_results_item_grouping import BillingBreakdownV1ResponseResultsItemGrouping
    from .cartesia import Cartesia
    from .cartesia_speak_provider_model_id import CartesiaSpeakProviderModelId
    from .cartesia_speak_provider_voice import CartesiaSpeakProviderVoice
    from .create_key_v1request_one import CreateKeyV1RequestOne
    from .create_key_v1response import CreateKeyV1Response
    from .create_project_distribution_credentials_v1response import CreateProjectDistributionCredentialsV1Response
    from .create_project_distribution_credentials_v1response_distribution_credentials import (
        CreateProjectDistributionCredentialsV1ResponseDistributionCredentials,
    )
    from .create_project_distribution_credentials_v1response_member import (
        CreateProjectDistributionCredentialsV1ResponseMember,
    )
    from .create_project_invite_v1response import CreateProjectInviteV1Response
    from .deepgram import Deepgram
    from .deepgram_speak_provider_model import DeepgramSpeakProviderModel
    from .delete_project_invite_v1response import DeleteProjectInviteV1Response
    from .delete_project_key_v1response import DeleteProjectKeyV1Response
    from .delete_project_member_v1response import DeleteProjectMemberV1Response
    from .delete_project_v1response import DeleteProjectV1Response
    from .eleven_labs_speak_provider import ElevenLabsSpeakProvider
    from .eleven_labs_speak_provider_model_id import ElevenLabsSpeakProviderModelId
    from .error_response import ErrorResponse
    from .error_response_legacy_error import ErrorResponseLegacyError
    from .error_response_modern_error import ErrorResponseModernError
    from .error_response_text_error import ErrorResponseTextError
    from .get_model_v1response import GetModelV1Response
    from .get_model_v1response_batch import GetModelV1ResponseBatch
    from .get_model_v1response_metadata import GetModelV1ResponseMetadata
    from .get_model_v1response_metadata_metadata import GetModelV1ResponseMetadataMetadata
    from .get_project_balance_v1response import GetProjectBalanceV1Response
    from .get_project_distribution_credentials_v1response import GetProjectDistributionCredentialsV1Response
    from .get_project_distribution_credentials_v1response_distribution_credentials import (
        GetProjectDistributionCredentialsV1ResponseDistributionCredentials,
    )
    from .get_project_distribution_credentials_v1response_member import (
        GetProjectDistributionCredentialsV1ResponseMember,
    )
    from .get_project_key_v1response import GetProjectKeyV1Response
    from .get_project_key_v1response_item import GetProjectKeyV1ResponseItem
    from .get_project_key_v1response_item_member import GetProjectKeyV1ResponseItemMember
    from .get_project_key_v1response_item_member_api_key import GetProjectKeyV1ResponseItemMemberApiKey
    from .get_project_request_v1response import GetProjectRequestV1Response
    from .get_project_v1response import GetProjectV1Response
    from .google import Google
    from .google_think_provider_model import GoogleThinkProviderModel
    from .grant_v1response import GrantV1Response
    from .groq import Groq
    from .leave_project_v1response import LeaveProjectV1Response
    from .list_billing_fields_v1response import ListBillingFieldsV1Response
    from .list_billing_fields_v1response_deployments_item import ListBillingFieldsV1ResponseDeploymentsItem
    from .list_models_v1response import ListModelsV1Response
    from .list_models_v1response_stt_models import ListModelsV1ResponseSttModels
    from .list_models_v1response_tts_models import ListModelsV1ResponseTtsModels
    from .list_models_v1response_tts_models_metadata import ListModelsV1ResponseTtsModelsMetadata
    from .list_project_balances_v1response import ListProjectBalancesV1Response
    from .list_project_balances_v1response_balances_item import ListProjectBalancesV1ResponseBalancesItem
    from .list_project_distribution_credentials_v1response import ListProjectDistributionCredentialsV1Response
    from .list_project_distribution_credentials_v1response_distribution_credentials_item import (
        ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItem,
    )
    from .list_project_distribution_credentials_v1response_distribution_credentials_item_distribution_credentials import (
        ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemDistributionCredentials,
    )
    from .list_project_distribution_credentials_v1response_distribution_credentials_item_member import (
        ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemMember,
    )
    from .list_project_invites_v1response import ListProjectInvitesV1Response
    from .list_project_invites_v1response_invites_item import ListProjectInvitesV1ResponseInvitesItem
    from .list_project_keys_v1response import ListProjectKeysV1Response
    from .list_project_keys_v1response_api_keys_item import ListProjectKeysV1ResponseApiKeysItem
    from .list_project_keys_v1response_api_keys_item_api_key import ListProjectKeysV1ResponseApiKeysItemApiKey
    from .list_project_keys_v1response_api_keys_item_member import ListProjectKeysV1ResponseApiKeysItemMember
    from .list_project_member_scopes_v1response import ListProjectMemberScopesV1Response
    from .list_project_members_v1response import ListProjectMembersV1Response
    from .list_project_members_v1response_members_item import ListProjectMembersV1ResponseMembersItem
    from .list_project_purchases_v1response import ListProjectPurchasesV1Response
    from .list_project_purchases_v1response_orders_item import ListProjectPurchasesV1ResponseOrdersItem
    from .list_project_requests_v1response import ListProjectRequestsV1Response
    from .list_projects_v1response import ListProjectsV1Response
    from .list_projects_v1response_projects_item import ListProjectsV1ResponseProjectsItem
    from .listen_v1accepted_response import ListenV1AcceptedResponse
    from .listen_v1callback import ListenV1Callback
    from .listen_v1callback_method import ListenV1CallbackMethod
    from .listen_v1channels import ListenV1Channels
    from .listen_v1detect_entities import ListenV1DetectEntities
    from .listen_v1diarize import ListenV1Diarize
    from .listen_v1dictation import ListenV1Dictation
    from .listen_v1encoding import ListenV1Encoding
    from .listen_v1endpointing import ListenV1Endpointing
    from .listen_v1extra import ListenV1Extra
    from .listen_v1interim_results import ListenV1InterimResults
    from .listen_v1keyterm import ListenV1Keyterm
    from .listen_v1keywords import ListenV1Keywords
    from .listen_v1language import ListenV1Language
    from .listen_v1mip_opt_out import ListenV1MipOptOut
    from .listen_v1model import ListenV1Model
    from .listen_v1multichannel import ListenV1Multichannel
    from .listen_v1numerals import ListenV1Numerals
    from .listen_v1profanity_filter import ListenV1ProfanityFilter
    from .listen_v1punctuate import ListenV1Punctuate
    from .listen_v1redact import ListenV1Redact
    from .listen_v1replace import ListenV1Replace
    from .listen_v1request_file import ListenV1RequestFile
    from .listen_v1response import ListenV1Response
    from .listen_v1response_metadata import ListenV1ResponseMetadata
    from .listen_v1response_metadata_intents_info import ListenV1ResponseMetadataIntentsInfo
    from .listen_v1response_metadata_sentiment_info import ListenV1ResponseMetadataSentimentInfo
    from .listen_v1response_metadata_summary_info import ListenV1ResponseMetadataSummaryInfo
    from .listen_v1response_metadata_topics_info import ListenV1ResponseMetadataTopicsInfo
    from .listen_v1response_results import ListenV1ResponseResults
    from .listen_v1response_results_channels import ListenV1ResponseResultsChannels
    from .listen_v1response_results_channels_item import ListenV1ResponseResultsChannelsItem
    from .listen_v1response_results_channels_item_alternatives_item import (
        ListenV1ResponseResultsChannelsItemAlternativesItem,
    )
    from .listen_v1response_results_channels_item_alternatives_item_entities_item import (
        ListenV1ResponseResultsChannelsItemAlternativesItemEntitiesItem,
    )
    from .listen_v1response_results_channels_item_alternatives_item_paragraphs import (
        ListenV1ResponseResultsChannelsItemAlternativesItemParagraphs,
    )
    from .listen_v1response_results_channels_item_alternatives_item_paragraphs_paragraphs_item import (
        ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItem,
    )
    from .listen_v1response_results_channels_item_alternatives_item_paragraphs_paragraphs_item_sentences_item import (
        ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemSentencesItem,
    )
    from .listen_v1response_results_channels_item_alternatives_item_summaries_item import (
        ListenV1ResponseResultsChannelsItemAlternativesItemSummariesItem,
    )
    from .listen_v1response_results_channels_item_alternatives_item_topics_item import (
        ListenV1ResponseResultsChannelsItemAlternativesItemTopicsItem,
    )
    from .listen_v1response_results_channels_item_alternatives_item_words_item import (
        ListenV1ResponseResultsChannelsItemAlternativesItemWordsItem,
    )
    from .listen_v1response_results_channels_item_search_item import ListenV1ResponseResultsChannelsItemSearchItem
    from .listen_v1response_results_channels_item_search_item_hits_item import (
        ListenV1ResponseResultsChannelsItemSearchItemHitsItem,
    )
    from .listen_v1response_results_summary import ListenV1ResponseResultsSummary
    from .listen_v1response_results_utterances import ListenV1ResponseResultsUtterances
    from .listen_v1response_results_utterances_item import ListenV1ResponseResultsUtterancesItem
    from .listen_v1response_results_utterances_item_words_item import ListenV1ResponseResultsUtterancesItemWordsItem
    from .listen_v1sample_rate import ListenV1SampleRate
    from .listen_v1search import ListenV1Search
    from .listen_v1smart_format import ListenV1SmartFormat
    from .listen_v1tag import ListenV1Tag
    from .listen_v1utterance_end_ms import ListenV1UtteranceEndMs
    from .listen_v1vad_events import ListenV1VadEvents
    from .listen_v1version import ListenV1Version
    from .listen_v2eager_eot_threshold import ListenV2EagerEotThreshold
    from .listen_v2encoding import ListenV2Encoding
    from .listen_v2eot_threshold import ListenV2EotThreshold
    from .listen_v2eot_timeout_ms import ListenV2EotTimeoutMs
    from .listen_v2keyterm import ListenV2Keyterm
    from .listen_v2mip_opt_out import ListenV2MipOptOut
    from .listen_v2model import ListenV2Model
    from .listen_v2sample_rate import ListenV2SampleRate
    from .listen_v2tag import ListenV2Tag
    from .open_ai_speak_provider import OpenAiSpeakProvider
    from .open_ai_speak_provider_model import OpenAiSpeakProviderModel
    from .open_ai_speak_provider_voice import OpenAiSpeakProviderVoice
    from .open_ai_think_provider import OpenAiThinkProvider
    from .open_ai_think_provider_model import OpenAiThinkProviderModel
    from .project_request_response import ProjectRequestResponse
    from .read_v1request import ReadV1Request
    from .read_v1request_text import ReadV1RequestText
    from .read_v1request_url import ReadV1RequestUrl
    from .read_v1response import ReadV1Response
    from .read_v1response_metadata import ReadV1ResponseMetadata
    from .read_v1response_metadata_metadata import ReadV1ResponseMetadataMetadata
    from .read_v1response_metadata_metadata_intents_info import ReadV1ResponseMetadataMetadataIntentsInfo
    from .read_v1response_metadata_metadata_sentiment_info import ReadV1ResponseMetadataMetadataSentimentInfo
    from .read_v1response_metadata_metadata_summary_info import ReadV1ResponseMetadataMetadataSummaryInfo
    from .read_v1response_metadata_metadata_topics_info import ReadV1ResponseMetadataMetadataTopicsInfo
    from .read_v1response_results import ReadV1ResponseResults
    from .read_v1response_results_summary import ReadV1ResponseResultsSummary
    from .read_v1response_results_summary_results import ReadV1ResponseResultsSummaryResults
    from .read_v1response_results_summary_results_summary import ReadV1ResponseResultsSummaryResultsSummary
    from .shared_intents import SharedIntents
    from .shared_intents_results import SharedIntentsResults
    from .shared_intents_results_intents import SharedIntentsResultsIntents
    from .shared_intents_results_intents_segments_item import SharedIntentsResultsIntentsSegmentsItem
    from .shared_intents_results_intents_segments_item_intents_item import (
        SharedIntentsResultsIntentsSegmentsItemIntentsItem,
    )
    from .shared_sentiments import SharedSentiments
    from .shared_sentiments_average import SharedSentimentsAverage
    from .shared_sentiments_segments_item import SharedSentimentsSegmentsItem
    from .shared_topics import SharedTopics
    from .shared_topics_results import SharedTopicsResults
    from .shared_topics_results_topics import SharedTopicsResultsTopics
    from .shared_topics_results_topics_segments_item import SharedTopicsResultsTopicsSegmentsItem
    from .shared_topics_results_topics_segments_item_topics_item import SharedTopicsResultsTopicsSegmentsItemTopicsItem
    from .speak_settings_v1 import SpeakSettingsV1
    from .speak_settings_v1endpoint import SpeakSettingsV1Endpoint
    from .speak_settings_v1provider import (
        SpeakSettingsV1Provider,
        SpeakSettingsV1Provider_AwsPolly,
        SpeakSettingsV1Provider_Cartesia,
        SpeakSettingsV1Provider_Deepgram,
        SpeakSettingsV1Provider_ElevenLabs,
        SpeakSettingsV1Provider_OpenAi,
    )
    from .speak_v1encoding import SpeakV1Encoding
    from .speak_v1mip_opt_out import SpeakV1MipOptOut
    from .speak_v1model import SpeakV1Model
    from .speak_v1response import SpeakV1Response
    from .speak_v1sample_rate import SpeakV1SampleRate
    from .think_settings_v1 import ThinkSettingsV1
    from .think_settings_v1context_length import ThinkSettingsV1ContextLength
    from .think_settings_v1endpoint import ThinkSettingsV1Endpoint
    from .think_settings_v1functions_item import ThinkSettingsV1FunctionsItem
    from .think_settings_v1functions_item_endpoint import ThinkSettingsV1FunctionsItemEndpoint
    from .think_settings_v1provider import (
        ThinkSettingsV1Provider,
        ThinkSettingsV1Provider_Anthropic,
        ThinkSettingsV1Provider_AwsBedrock,
        ThinkSettingsV1Provider_Google,
        ThinkSettingsV1Provider_Groq,
        ThinkSettingsV1Provider_OpenAi,
    )
    from .update_project_member_scopes_v1response import UpdateProjectMemberScopesV1Response
    from .update_project_v1response import UpdateProjectV1Response
    from .usage_breakdown_v1response import UsageBreakdownV1Response
    from .usage_breakdown_v1response_resolution import UsageBreakdownV1ResponseResolution
    from .usage_breakdown_v1response_results_item import UsageBreakdownV1ResponseResultsItem
    from .usage_breakdown_v1response_results_item_grouping import UsageBreakdownV1ResponseResultsItemGrouping
    from .usage_fields_v1response import UsageFieldsV1Response
    from .usage_fields_v1response_models_item import UsageFieldsV1ResponseModelsItem
    from .usage_v1response import UsageV1Response
    from .usage_v1response_resolution import UsageV1ResponseResolution
_dynamic_imports: typing.Dict[str, str] = {
    "AgentThinkModelsV1Response": ".agent_think_models_v1response",
    "AgentThinkModelsV1ResponseModelsItem": ".agent_think_models_v1response_models_item",
    "AgentThinkModelsV1ResponseModelsItemId": ".agent_think_models_v1response_models_item_id",
    "AgentThinkModelsV1ResponseModelsItemOne": ".agent_think_models_v1response_models_item_one",
    "AgentThinkModelsV1ResponseModelsItemOneId": ".agent_think_models_v1response_models_item_one_id",
    "AgentThinkModelsV1ResponseModelsItemThree": ".agent_think_models_v1response_models_item_three",
    "AgentThinkModelsV1ResponseModelsItemTwo": ".agent_think_models_v1response_models_item_two",
    "AgentThinkModelsV1ResponseModelsItemTwoId": ".agent_think_models_v1response_models_item_two_id",
    "AgentThinkModelsV1ResponseModelsItemZero": ".agent_think_models_v1response_models_item_zero",
    "AgentThinkModelsV1ResponseModelsItemZeroId": ".agent_think_models_v1response_models_item_zero_id",
    "Anthropic": ".anthropic",
    "AnthropicThinkProviderModel": ".anthropic_think_provider_model",
    "AwsBedrockThinkProvider": ".aws_bedrock_think_provider",
    "AwsBedrockThinkProviderCredentials": ".aws_bedrock_think_provider_credentials",
    "AwsBedrockThinkProviderCredentialsType": ".aws_bedrock_think_provider_credentials_type",
    "AwsBedrockThinkProviderModel": ".aws_bedrock_think_provider_model",
    "AwsPollySpeakProvider": ".aws_polly_speak_provider",
    "AwsPollySpeakProviderCredentials": ".aws_polly_speak_provider_credentials",
    "AwsPollySpeakProviderCredentialsType": ".aws_polly_speak_provider_credentials_type",
    "AwsPollySpeakProviderEngine": ".aws_polly_speak_provider_engine",
    "AwsPollySpeakProviderVoice": ".aws_polly_speak_provider_voice",
    "BillingBreakdownV1Response": ".billing_breakdown_v1response",
    "BillingBreakdownV1ResponseResolution": ".billing_breakdown_v1response_resolution",
    "BillingBreakdownV1ResponseResultsItem": ".billing_breakdown_v1response_results_item",
    "BillingBreakdownV1ResponseResultsItemGrouping": ".billing_breakdown_v1response_results_item_grouping",
    "Cartesia": ".cartesia",
    "CartesiaSpeakProviderModelId": ".cartesia_speak_provider_model_id",
    "CartesiaSpeakProviderVoice": ".cartesia_speak_provider_voice",
    "CreateKeyV1RequestOne": ".create_key_v1request_one",
    "CreateKeyV1Response": ".create_key_v1response",
    "CreateProjectDistributionCredentialsV1Response": ".create_project_distribution_credentials_v1response",
    "CreateProjectDistributionCredentialsV1ResponseDistributionCredentials": ".create_project_distribution_credentials_v1response_distribution_credentials",
    "CreateProjectDistributionCredentialsV1ResponseMember": ".create_project_distribution_credentials_v1response_member",
    "CreateProjectInviteV1Response": ".create_project_invite_v1response",
    "Deepgram": ".deepgram",
    "DeepgramSpeakProviderModel": ".deepgram_speak_provider_model",
    "DeleteProjectInviteV1Response": ".delete_project_invite_v1response",
    "DeleteProjectKeyV1Response": ".delete_project_key_v1response",
    "DeleteProjectMemberV1Response": ".delete_project_member_v1response",
    "DeleteProjectV1Response": ".delete_project_v1response",
    "ElevenLabsSpeakProvider": ".eleven_labs_speak_provider",
    "ElevenLabsSpeakProviderModelId": ".eleven_labs_speak_provider_model_id",
    "ErrorResponse": ".error_response",
    "ErrorResponseLegacyError": ".error_response_legacy_error",
    "ErrorResponseModernError": ".error_response_modern_error",
    "ErrorResponseTextError": ".error_response_text_error",
    "GetModelV1Response": ".get_model_v1response",
    "GetModelV1ResponseBatch": ".get_model_v1response_batch",
    "GetModelV1ResponseMetadata": ".get_model_v1response_metadata",
    "GetModelV1ResponseMetadataMetadata": ".get_model_v1response_metadata_metadata",
    "GetProjectBalanceV1Response": ".get_project_balance_v1response",
    "GetProjectDistributionCredentialsV1Response": ".get_project_distribution_credentials_v1response",
    "GetProjectDistributionCredentialsV1ResponseDistributionCredentials": ".get_project_distribution_credentials_v1response_distribution_credentials",
    "GetProjectDistributionCredentialsV1ResponseMember": ".get_project_distribution_credentials_v1response_member",
    "GetProjectKeyV1Response": ".get_project_key_v1response",
    "GetProjectKeyV1ResponseItem": ".get_project_key_v1response_item",
    "GetProjectKeyV1ResponseItemMember": ".get_project_key_v1response_item_member",
    "GetProjectKeyV1ResponseItemMemberApiKey": ".get_project_key_v1response_item_member_api_key",
    "GetProjectRequestV1Response": ".get_project_request_v1response",
    "GetProjectV1Response": ".get_project_v1response",
    "Google": ".google",
    "GoogleThinkProviderModel": ".google_think_provider_model",
    "GrantV1Response": ".grant_v1response",
    "Groq": ".groq",
    "LeaveProjectV1Response": ".leave_project_v1response",
    "ListBillingFieldsV1Response": ".list_billing_fields_v1response",
    "ListBillingFieldsV1ResponseDeploymentsItem": ".list_billing_fields_v1response_deployments_item",
    "ListModelsV1Response": ".list_models_v1response",
    "ListModelsV1ResponseSttModels": ".list_models_v1response_stt_models",
    "ListModelsV1ResponseTtsModels": ".list_models_v1response_tts_models",
    "ListModelsV1ResponseTtsModelsMetadata": ".list_models_v1response_tts_models_metadata",
    "ListProjectBalancesV1Response": ".list_project_balances_v1response",
    "ListProjectBalancesV1ResponseBalancesItem": ".list_project_balances_v1response_balances_item",
    "ListProjectDistributionCredentialsV1Response": ".list_project_distribution_credentials_v1response",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItem": ".list_project_distribution_credentials_v1response_distribution_credentials_item",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemDistributionCredentials": ".list_project_distribution_credentials_v1response_distribution_credentials_item_distribution_credentials",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemMember": ".list_project_distribution_credentials_v1response_distribution_credentials_item_member",
    "ListProjectInvitesV1Response": ".list_project_invites_v1response",
    "ListProjectInvitesV1ResponseInvitesItem": ".list_project_invites_v1response_invites_item",
    "ListProjectKeysV1Response": ".list_project_keys_v1response",
    "ListProjectKeysV1ResponseApiKeysItem": ".list_project_keys_v1response_api_keys_item",
    "ListProjectKeysV1ResponseApiKeysItemApiKey": ".list_project_keys_v1response_api_keys_item_api_key",
    "ListProjectKeysV1ResponseApiKeysItemMember": ".list_project_keys_v1response_api_keys_item_member",
    "ListProjectMemberScopesV1Response": ".list_project_member_scopes_v1response",
    "ListProjectMembersV1Response": ".list_project_members_v1response",
    "ListProjectMembersV1ResponseMembersItem": ".list_project_members_v1response_members_item",
    "ListProjectPurchasesV1Response": ".list_project_purchases_v1response",
    "ListProjectPurchasesV1ResponseOrdersItem": ".list_project_purchases_v1response_orders_item",
    "ListProjectRequestsV1Response": ".list_project_requests_v1response",
    "ListProjectsV1Response": ".list_projects_v1response",
    "ListProjectsV1ResponseProjectsItem": ".list_projects_v1response_projects_item",
    "ListenV1AcceptedResponse": ".listen_v1accepted_response",
    "ListenV1Callback": ".listen_v1callback",
    "ListenV1CallbackMethod": ".listen_v1callback_method",
    "ListenV1Channels": ".listen_v1channels",
    "ListenV1DetectEntities": ".listen_v1detect_entities",
    "ListenV1Diarize": ".listen_v1diarize",
    "ListenV1Dictation": ".listen_v1dictation",
    "ListenV1Encoding": ".listen_v1encoding",
    "ListenV1Endpointing": ".listen_v1endpointing",
    "ListenV1Extra": ".listen_v1extra",
    "ListenV1InterimResults": ".listen_v1interim_results",
    "ListenV1Keyterm": ".listen_v1keyterm",
    "ListenV1Keywords": ".listen_v1keywords",
    "ListenV1Language": ".listen_v1language",
    "ListenV1MipOptOut": ".listen_v1mip_opt_out",
    "ListenV1Model": ".listen_v1model",
    "ListenV1Multichannel": ".listen_v1multichannel",
    "ListenV1Numerals": ".listen_v1numerals",
    "ListenV1ProfanityFilter": ".listen_v1profanity_filter",
    "ListenV1Punctuate": ".listen_v1punctuate",
    "ListenV1Redact": ".listen_v1redact",
    "ListenV1Replace": ".listen_v1replace",
    "ListenV1RequestFile": ".listen_v1request_file",
    "ListenV1Response": ".listen_v1response",
    "ListenV1ResponseMetadata": ".listen_v1response_metadata",
    "ListenV1ResponseMetadataIntentsInfo": ".listen_v1response_metadata_intents_info",
    "ListenV1ResponseMetadataSentimentInfo": ".listen_v1response_metadata_sentiment_info",
    "ListenV1ResponseMetadataSummaryInfo": ".listen_v1response_metadata_summary_info",
    "ListenV1ResponseMetadataTopicsInfo": ".listen_v1response_metadata_topics_info",
    "ListenV1ResponseResults": ".listen_v1response_results",
    "ListenV1ResponseResultsChannels": ".listen_v1response_results_channels",
    "ListenV1ResponseResultsChannelsItem": ".listen_v1response_results_channels_item",
    "ListenV1ResponseResultsChannelsItemAlternativesItem": ".listen_v1response_results_channels_item_alternatives_item",
    "ListenV1ResponseResultsChannelsItemAlternativesItemEntitiesItem": ".listen_v1response_results_channels_item_alternatives_item_entities_item",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphs": ".listen_v1response_results_channels_item_alternatives_item_paragraphs",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItem": ".listen_v1response_results_channels_item_alternatives_item_paragraphs_paragraphs_item",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemSentencesItem": ".listen_v1response_results_channels_item_alternatives_item_paragraphs_paragraphs_item_sentences_item",
    "ListenV1ResponseResultsChannelsItemAlternativesItemSummariesItem": ".listen_v1response_results_channels_item_alternatives_item_summaries_item",
    "ListenV1ResponseResultsChannelsItemAlternativesItemTopicsItem": ".listen_v1response_results_channels_item_alternatives_item_topics_item",
    "ListenV1ResponseResultsChannelsItemAlternativesItemWordsItem": ".listen_v1response_results_channels_item_alternatives_item_words_item",
    "ListenV1ResponseResultsChannelsItemSearchItem": ".listen_v1response_results_channels_item_search_item",
    "ListenV1ResponseResultsChannelsItemSearchItemHitsItem": ".listen_v1response_results_channels_item_search_item_hits_item",
    "ListenV1ResponseResultsSummary": ".listen_v1response_results_summary",
    "ListenV1ResponseResultsUtterances": ".listen_v1response_results_utterances",
    "ListenV1ResponseResultsUtterancesItem": ".listen_v1response_results_utterances_item",
    "ListenV1ResponseResultsUtterancesItemWordsItem": ".listen_v1response_results_utterances_item_words_item",
    "ListenV1SampleRate": ".listen_v1sample_rate",
    "ListenV1Search": ".listen_v1search",
    "ListenV1SmartFormat": ".listen_v1smart_format",
    "ListenV1Tag": ".listen_v1tag",
    "ListenV1UtteranceEndMs": ".listen_v1utterance_end_ms",
    "ListenV1VadEvents": ".listen_v1vad_events",
    "ListenV1Version": ".listen_v1version",
    "ListenV2EagerEotThreshold": ".listen_v2eager_eot_threshold",
    "ListenV2Encoding": ".listen_v2encoding",
    "ListenV2EotThreshold": ".listen_v2eot_threshold",
    "ListenV2EotTimeoutMs": ".listen_v2eot_timeout_ms",
    "ListenV2Keyterm": ".listen_v2keyterm",
    "ListenV2MipOptOut": ".listen_v2mip_opt_out",
    "ListenV2Model": ".listen_v2model",
    "ListenV2SampleRate": ".listen_v2sample_rate",
    "ListenV2Tag": ".listen_v2tag",
    "OpenAiSpeakProvider": ".open_ai_speak_provider",
    "OpenAiSpeakProviderModel": ".open_ai_speak_provider_model",
    "OpenAiSpeakProviderVoice": ".open_ai_speak_provider_voice",
    "OpenAiThinkProvider": ".open_ai_think_provider",
    "OpenAiThinkProviderModel": ".open_ai_think_provider_model",
    "ProjectRequestResponse": ".project_request_response",
    "ReadV1Request": ".read_v1request",
    "ReadV1RequestText": ".read_v1request_text",
    "ReadV1RequestUrl": ".read_v1request_url",
    "ReadV1Response": ".read_v1response",
    "ReadV1ResponseMetadata": ".read_v1response_metadata",
    "ReadV1ResponseMetadataMetadata": ".read_v1response_metadata_metadata",
    "ReadV1ResponseMetadataMetadataIntentsInfo": ".read_v1response_metadata_metadata_intents_info",
    "ReadV1ResponseMetadataMetadataSentimentInfo": ".read_v1response_metadata_metadata_sentiment_info",
    "ReadV1ResponseMetadataMetadataSummaryInfo": ".read_v1response_metadata_metadata_summary_info",
    "ReadV1ResponseMetadataMetadataTopicsInfo": ".read_v1response_metadata_metadata_topics_info",
    "ReadV1ResponseResults": ".read_v1response_results",
    "ReadV1ResponseResultsSummary": ".read_v1response_results_summary",
    "ReadV1ResponseResultsSummaryResults": ".read_v1response_results_summary_results",
    "ReadV1ResponseResultsSummaryResultsSummary": ".read_v1response_results_summary_results_summary",
    "SharedIntents": ".shared_intents",
    "SharedIntentsResults": ".shared_intents_results",
    "SharedIntentsResultsIntents": ".shared_intents_results_intents",
    "SharedIntentsResultsIntentsSegmentsItem": ".shared_intents_results_intents_segments_item",
    "SharedIntentsResultsIntentsSegmentsItemIntentsItem": ".shared_intents_results_intents_segments_item_intents_item",
    "SharedSentiments": ".shared_sentiments",
    "SharedSentimentsAverage": ".shared_sentiments_average",
    "SharedSentimentsSegmentsItem": ".shared_sentiments_segments_item",
    "SharedTopics": ".shared_topics",
    "SharedTopicsResults": ".shared_topics_results",
    "SharedTopicsResultsTopics": ".shared_topics_results_topics",
    "SharedTopicsResultsTopicsSegmentsItem": ".shared_topics_results_topics_segments_item",
    "SharedTopicsResultsTopicsSegmentsItemTopicsItem": ".shared_topics_results_topics_segments_item_topics_item",
    "SpeakSettingsV1": ".speak_settings_v1",
    "SpeakSettingsV1Endpoint": ".speak_settings_v1endpoint",
    "SpeakSettingsV1Provider": ".speak_settings_v1provider",
    "SpeakSettingsV1Provider_AwsPolly": ".speak_settings_v1provider",
    "SpeakSettingsV1Provider_Cartesia": ".speak_settings_v1provider",
    "SpeakSettingsV1Provider_Deepgram": ".speak_settings_v1provider",
    "SpeakSettingsV1Provider_ElevenLabs": ".speak_settings_v1provider",
    "SpeakSettingsV1Provider_OpenAi": ".speak_settings_v1provider",
    "SpeakV1Encoding": ".speak_v1encoding",
    "SpeakV1MipOptOut": ".speak_v1mip_opt_out",
    "SpeakV1Model": ".speak_v1model",
    "SpeakV1Response": ".speak_v1response",
    "SpeakV1SampleRate": ".speak_v1sample_rate",
    "ThinkSettingsV1": ".think_settings_v1",
    "ThinkSettingsV1ContextLength": ".think_settings_v1context_length",
    "ThinkSettingsV1Endpoint": ".think_settings_v1endpoint",
    "ThinkSettingsV1FunctionsItem": ".think_settings_v1functions_item",
    "ThinkSettingsV1FunctionsItemEndpoint": ".think_settings_v1functions_item_endpoint",
    "ThinkSettingsV1Provider": ".think_settings_v1provider",
    "ThinkSettingsV1Provider_Anthropic": ".think_settings_v1provider",
    "ThinkSettingsV1Provider_AwsBedrock": ".think_settings_v1provider",
    "ThinkSettingsV1Provider_Google": ".think_settings_v1provider",
    "ThinkSettingsV1Provider_Groq": ".think_settings_v1provider",
    "ThinkSettingsV1Provider_OpenAi": ".think_settings_v1provider",
    "UpdateProjectMemberScopesV1Response": ".update_project_member_scopes_v1response",
    "UpdateProjectV1Response": ".update_project_v1response",
    "UsageBreakdownV1Response": ".usage_breakdown_v1response",
    "UsageBreakdownV1ResponseResolution": ".usage_breakdown_v1response_resolution",
    "UsageBreakdownV1ResponseResultsItem": ".usage_breakdown_v1response_results_item",
    "UsageBreakdownV1ResponseResultsItemGrouping": ".usage_breakdown_v1response_results_item_grouping",
    "UsageFieldsV1Response": ".usage_fields_v1response",
    "UsageFieldsV1ResponseModelsItem": ".usage_fields_v1response_models_item",
    "UsageV1Response": ".usage_v1response",
    "UsageV1ResponseResolution": ".usage_v1response_resolution",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AgentThinkModelsV1Response",
    "AgentThinkModelsV1ResponseModelsItem",
    "AgentThinkModelsV1ResponseModelsItemId",
    "AgentThinkModelsV1ResponseModelsItemOne",
    "AgentThinkModelsV1ResponseModelsItemOneId",
    "AgentThinkModelsV1ResponseModelsItemThree",
    "AgentThinkModelsV1ResponseModelsItemTwo",
    "AgentThinkModelsV1ResponseModelsItemTwoId",
    "AgentThinkModelsV1ResponseModelsItemZero",
    "AgentThinkModelsV1ResponseModelsItemZeroId",
    "Anthropic",
    "AnthropicThinkProviderModel",
    "AwsBedrockThinkProvider",
    "AwsBedrockThinkProviderCredentials",
    "AwsBedrockThinkProviderCredentialsType",
    "AwsBedrockThinkProviderModel",
    "AwsPollySpeakProvider",
    "AwsPollySpeakProviderCredentials",
    "AwsPollySpeakProviderCredentialsType",
    "AwsPollySpeakProviderEngine",
    "AwsPollySpeakProviderVoice",
    "BillingBreakdownV1Response",
    "BillingBreakdownV1ResponseResolution",
    "BillingBreakdownV1ResponseResultsItem",
    "BillingBreakdownV1ResponseResultsItemGrouping",
    "Cartesia",
    "CartesiaSpeakProviderModelId",
    "CartesiaSpeakProviderVoice",
    "CreateKeyV1RequestOne",
    "CreateKeyV1Response",
    "CreateProjectDistributionCredentialsV1Response",
    "CreateProjectDistributionCredentialsV1ResponseDistributionCredentials",
    "CreateProjectDistributionCredentialsV1ResponseMember",
    "CreateProjectInviteV1Response",
    "Deepgram",
    "DeepgramSpeakProviderModel",
    "DeleteProjectInviteV1Response",
    "DeleteProjectKeyV1Response",
    "DeleteProjectMemberV1Response",
    "DeleteProjectV1Response",
    "ElevenLabsSpeakProvider",
    "ElevenLabsSpeakProviderModelId",
    "ErrorResponse",
    "ErrorResponseLegacyError",
    "ErrorResponseModernError",
    "ErrorResponseTextError",
    "GetModelV1Response",
    "GetModelV1ResponseBatch",
    "GetModelV1ResponseMetadata",
    "GetModelV1ResponseMetadataMetadata",
    "GetProjectBalanceV1Response",
    "GetProjectDistributionCredentialsV1Response",
    "GetProjectDistributionCredentialsV1ResponseDistributionCredentials",
    "GetProjectDistributionCredentialsV1ResponseMember",
    "GetProjectKeyV1Response",
    "GetProjectKeyV1ResponseItem",
    "GetProjectKeyV1ResponseItemMember",
    "GetProjectKeyV1ResponseItemMemberApiKey",
    "GetProjectRequestV1Response",
    "GetProjectV1Response",
    "Google",
    "GoogleThinkProviderModel",
    "GrantV1Response",
    "Groq",
    "LeaveProjectV1Response",
    "ListBillingFieldsV1Response",
    "ListBillingFieldsV1ResponseDeploymentsItem",
    "ListModelsV1Response",
    "ListModelsV1ResponseSttModels",
    "ListModelsV1ResponseTtsModels",
    "ListModelsV1ResponseTtsModelsMetadata",
    "ListProjectBalancesV1Response",
    "ListProjectBalancesV1ResponseBalancesItem",
    "ListProjectDistributionCredentialsV1Response",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItem",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemDistributionCredentials",
    "ListProjectDistributionCredentialsV1ResponseDistributionCredentialsItemMember",
    "ListProjectInvitesV1Response",
    "ListProjectInvitesV1ResponseInvitesItem",
    "ListProjectKeysV1Response",
    "ListProjectKeysV1ResponseApiKeysItem",
    "ListProjectKeysV1ResponseApiKeysItemApiKey",
    "ListProjectKeysV1ResponseApiKeysItemMember",
    "ListProjectMemberScopesV1Response",
    "ListProjectMembersV1Response",
    "ListProjectMembersV1ResponseMembersItem",
    "ListProjectPurchasesV1Response",
    "ListProjectPurchasesV1ResponseOrdersItem",
    "ListProjectRequestsV1Response",
    "ListProjectsV1Response",
    "ListProjectsV1ResponseProjectsItem",
    "ListenV1AcceptedResponse",
    "ListenV1Callback",
    "ListenV1CallbackMethod",
    "ListenV1Channels",
    "ListenV1DetectEntities",
    "ListenV1Diarize",
    "ListenV1Dictation",
    "ListenV1Encoding",
    "ListenV1Endpointing",
    "ListenV1Extra",
    "ListenV1InterimResults",
    "ListenV1Keyterm",
    "ListenV1Keywords",
    "ListenV1Language",
    "ListenV1MipOptOut",
    "ListenV1Model",
    "ListenV1Multichannel",
    "ListenV1Numerals",
    "ListenV1ProfanityFilter",
    "ListenV1Punctuate",
    "ListenV1Redact",
    "ListenV1Replace",
    "ListenV1RequestFile",
    "ListenV1Response",
    "ListenV1ResponseMetadata",
    "ListenV1ResponseMetadataIntentsInfo",
    "ListenV1ResponseMetadataSentimentInfo",
    "ListenV1ResponseMetadataSummaryInfo",
    "ListenV1ResponseMetadataTopicsInfo",
    "ListenV1ResponseResults",
    "ListenV1ResponseResultsChannels",
    "ListenV1ResponseResultsChannelsItem",
    "ListenV1ResponseResultsChannelsItemAlternativesItem",
    "ListenV1ResponseResultsChannelsItemAlternativesItemEntitiesItem",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphs",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItem",
    "ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemSentencesItem",
    "ListenV1ResponseResultsChannelsItemAlternativesItemSummariesItem",
    "ListenV1ResponseResultsChannelsItemAlternativesItemTopicsItem",
    "ListenV1ResponseResultsChannelsItemAlternativesItemWordsItem",
    "ListenV1ResponseResultsChannelsItemSearchItem",
    "ListenV1ResponseResultsChannelsItemSearchItemHitsItem",
    "ListenV1ResponseResultsSummary",
    "ListenV1ResponseResultsUtterances",
    "ListenV1ResponseResultsUtterancesItem",
    "ListenV1ResponseResultsUtterancesItemWordsItem",
    "ListenV1SampleRate",
    "ListenV1Search",
    "ListenV1SmartFormat",
    "ListenV1Tag",
    "ListenV1UtteranceEndMs",
    "ListenV1VadEvents",
    "ListenV1Version",
    "ListenV2EagerEotThreshold",
    "ListenV2Encoding",
    "ListenV2EotThreshold",
    "ListenV2EotTimeoutMs",
    "ListenV2Keyterm",
    "ListenV2MipOptOut",
    "ListenV2Model",
    "ListenV2SampleRate",
    "ListenV2Tag",
    "OpenAiSpeakProvider",
    "OpenAiSpeakProviderModel",
    "OpenAiSpeakProviderVoice",
    "OpenAiThinkProvider",
    "OpenAiThinkProviderModel",
    "ProjectRequestResponse",
    "ReadV1Request",
    "ReadV1RequestText",
    "ReadV1RequestUrl",
    "ReadV1Response",
    "ReadV1ResponseMetadata",
    "ReadV1ResponseMetadataMetadata",
    "ReadV1ResponseMetadataMetadataIntentsInfo",
    "ReadV1ResponseMetadataMetadataSentimentInfo",
    "ReadV1ResponseMetadataMetadataSummaryInfo",
    "ReadV1ResponseMetadataMetadataTopicsInfo",
    "ReadV1ResponseResults",
    "ReadV1ResponseResultsSummary",
    "ReadV1ResponseResultsSummaryResults",
    "ReadV1ResponseResultsSummaryResultsSummary",
    "SharedIntents",
    "SharedIntentsResults",
    "SharedIntentsResultsIntents",
    "SharedIntentsResultsIntentsSegmentsItem",
    "SharedIntentsResultsIntentsSegmentsItemIntentsItem",
    "SharedSentiments",
    "SharedSentimentsAverage",
    "SharedSentimentsSegmentsItem",
    "SharedTopics",
    "SharedTopicsResults",
    "SharedTopicsResultsTopics",
    "SharedTopicsResultsTopicsSegmentsItem",
    "SharedTopicsResultsTopicsSegmentsItemTopicsItem",
    "SpeakSettingsV1",
    "SpeakSettingsV1Endpoint",
    "SpeakSettingsV1Provider",
    "SpeakSettingsV1Provider_AwsPolly",
    "SpeakSettingsV1Provider_Cartesia",
    "SpeakSettingsV1Provider_Deepgram",
    "SpeakSettingsV1Provider_ElevenLabs",
    "SpeakSettingsV1Provider_OpenAi",
    "SpeakV1Encoding",
    "SpeakV1MipOptOut",
    "SpeakV1Model",
    "SpeakV1Response",
    "SpeakV1SampleRate",
    "ThinkSettingsV1",
    "ThinkSettingsV1ContextLength",
    "ThinkSettingsV1Endpoint",
    "ThinkSettingsV1FunctionsItem",
    "ThinkSettingsV1FunctionsItemEndpoint",
    "ThinkSettingsV1Provider",
    "ThinkSettingsV1Provider_Anthropic",
    "ThinkSettingsV1Provider_AwsBedrock",
    "ThinkSettingsV1Provider_Google",
    "ThinkSettingsV1Provider_Groq",
    "ThinkSettingsV1Provider_OpenAi",
    "UpdateProjectMemberScopesV1Response",
    "UpdateProjectV1Response",
    "UsageBreakdownV1Response",
    "UsageBreakdownV1ResponseResolution",
    "UsageBreakdownV1ResponseResultsItem",
    "UsageBreakdownV1ResponseResultsItemGrouping",
    "UsageFieldsV1Response",
    "UsageFieldsV1ResponseModelsItem",
    "UsageV1Response",
    "UsageV1ResponseResolution",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .eleven_labs_speak_provider_model_id import ElevenLabsSpeakProviderModelId


class ElevenLabsSpeakProvider(UniversalBaseModel):
    type: typing.Literal["eleven_labs"] = "eleven_labs"
    version: typing.Optional[typing.Literal["v1"]] = pydantic.Field(default=None)
    """
    The REST API version for the ElevenLabs text-to-speech API
    """

    model_id: ElevenLabsSpeakProviderModelId = pydantic.Field()
    """
    Eleven Labs model ID
    """

    language: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional language to use, e.g. 'en-US'. Corresponds to the `language_code` parameter in the ElevenLabs API
    """

    language_code: typing.Optional[str] = pydantic.Field(default=None)
    """
    Use the `language` field instead.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ErrorResponseLegacyErrorParams(typing_extensions.TypedDict):
    err_code: typing_extensions.NotRequired[str]
    """
    The error code
    """

    err_msg: typing_extensions.NotRequired[str]
    """
    The error message
    """

    request_id: typing_extensions.NotRequired[str]
    """
    The request ID
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .listen_v1response_results_channels_item_alternatives_item import (
    ListenV1ResponseResultsChannelsItemAlternativesItem,
)
from .listen_v1response_results_channels_item_search_item import ListenV1ResponseResultsChannelsItemSearchItem


class ListenV1ResponseResultsChannelsItem(UniversalBaseModel):
    search: typing.Optional[typing.List[ListenV1ResponseResultsChannelsItemSearchItem]] = None
    alternatives: typing.Optional[typing.List[ListenV1ResponseResultsChannelsItemAlternativesItem]] = None
    detected_language: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .agent_v1settings_agent import AgentV1SettingsAgent
from .agent_v1settings_audio import AgentV1SettingsAudio
from .agent_v1settings_flags import AgentV1SettingsFlags


class AgentV1Settings(UniversalBaseModel):
    type: typing.Literal["Settings"] = "Settings"
    tags: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Tags to associate with the request
    """

    experimental: typing.Optional[bool] = pydantic.Field(default=None)
    """
    To enable experimental features
    """

    flags: typing.Optional[AgentV1SettingsFlags] = None
    mip_opt_out: typing.Optional[bool] = pydantic.Field(default=None)
    """
    To opt out of Deepgram Model Improvement Program
    """

    audio: AgentV1SettingsAudio
    agent: AgentV1SettingsAgent

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .billing_breakdown_v1response_results_item_grouping import BillingBreakdownV1ResponseResultsItemGrouping


class BillingBreakdownV1ResponseResultsItem(UniversalBaseModel):
    dollars: float = pydantic.Field()
    """
    USD cost of the billing for this grouping
    """

    grouping: BillingBreakdownV1ResponseResultsItemGrouping

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..types.speak_v1cleared_type import SpeakV1ClearedType


class SpeakV1ClearedParams(typing_extensions.TypedDict):
    type: SpeakV1ClearedType
    """
    Message type identifier
    """

    sequence_id: float
    """
    The sequence ID of the response
    """



# This file was auto-generated by Fern from our API Definition.

import typing

from .error_response_legacy_error import ErrorResponseLegacyError
from .error_response_modern_error import ErrorResponseModernError
from .error_response_text_error import ErrorResponseTextError

ErrorResponse = typing.Union[ErrorResponseTextError, ErrorResponseLegacyError, ErrorResponseModernError]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .usage_breakdown_v1response_results_item_grouping import UsageBreakdownV1ResponseResultsItemGrouping


class UsageBreakdownV1ResponseResultsItem(UniversalBaseModel):
    hours: float = pydantic.Field()
    """
    Audio hours processed
    """

    total_hours: float = pydantic.Field()
    """
    Total hours including all processing
    """

    agent_hours: float = pydantic.Field()
    """
    Agent hours used
    """

    tokens_in: float = pydantic.Field()
    """
    Number of input tokens
    """

    tokens_out: float = pydantic.Field()
    """
    Number of output tokens
    """

    tts_characters: float = pydantic.Field()
    """
    Number of text-to-speech characters processed
    """

    requests: float = pydantic.Field()
    """
    Number of requests
    """

    grouping: UsageBreakdownV1ResponseResultsItemGrouping

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
